@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8195 $
+## |  Last changed: $Date: 2024-09-11 14:50:27 +0200 (Mi, 11 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -46,12 +46,15 @@ NULL
 #'   \item \code{\link[=print.FieldSet]{print()}} to print the object,
 #'   \item \code{\link[=summary.TrialDesignSet]{summary()}} to display a summary of the object,
 #'   \item \code{\link[=plot.TrialDesignSet]{plot()}} to plot the object,
-#'   \item \code{\link[=as.data.frame.TrialDesignSet]{as.data.frame()}} to coerce the object to a \code{\link[base]{data.frame}},
-#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}} to coerce the object to a \code{\link[base]{matrix}}.
+#'   \item \code{\link[=as.data.frame.TrialDesignSet]{as.data.frame()}}
+#'         to coerce the object to a \code{\link[base]{data.frame}},
+#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}}
+#'         to coerce the object to a \code{\link[base]{matrix}}.
 #' }
 #' @template how_to_get_help_for_generics
 #'
 #' @examples
+#' \dontrun{
 #' # Example 1
 #' design <- getDesignGroupSequential(
 #'     alpha = 0.05, kMax = 6,
@@ -59,9 +62,7 @@ NULL
 #' )
 #' designSet <- getDesignSet()
 #' designSet$add(design = design, deltaWT = c(0.3, 0.4))
-#' \dontrun{
 #' if (require(ggplot2)) plot(designSet, type = 1)
-#' }
 #'
 #' # Example 2 (shorter script)
 #' design <- getDesignGroupSequential(
@@ -69,9 +70,7 @@ NULL
 #'     sided = 2, typeOfDesign = "WT", deltaWT = 0.1
 #' )
 #' designSet <- getDesignSet(design = design, deltaWT = c(0.3, 0.4))
-#' \dontrun{
 #' if (require(ggplot2)) plot(designSet, type = 1)
-#' }
 #'
 #' # Example 3 (use of designs instead of design)
 #' d1 <- getDesignGroupSequential(
@@ -88,14 +87,13 @@ NULL
 #'     designs = c(d1, d2),
 #'     variedParameters = c("typeOfDesign", "kMax")
 #' )
-#' \dontrun{
 #' if (require(ggplot2)) plot(designSet, type = 8, nMax = 20)
 #' }
 #'
 #' @export
 #'
 getDesignSet <- function(...) {
-    return(TrialDesignSet(...))
+    return(TrialDesignSet$new(...))
 }
 
 #'
@@ -126,7 +124,15 @@ summary.TrialDesignSet <- function(object, ..., type = 1, digits = NA_integer_)
 
     .assertIsTrialDesignSet(object)
     if (object$isEmpty()) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "cannot create summary because the design set is empty")
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "cannot create summary because the design set is empty"
+        )
+    }
+    
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("summary")
     }
 
     summaries <- list()
@@ -134,9 +140,97 @@ summary.TrialDesignSet <- function(object, ..., type = 1, digits = NA_integer_)
         s <- .createSummary(design, digits = digits)
         summaries <- c(summaries, s)
     }
+    summaries <- structure(summaries, class = "TrialDesignSummaries")
+    attr(summaries, "object") <- object
+    if (isTRUE(markdown)) {
+        attr(object, "markdown") <- TRUE
+        queue <- attr(object, "queue")
+        if (is.null(queue)) {
+            queue <- list()
+        }
+        queue[[length(queue) + 1]] <- object
+        attr(object, "queue") <- queue
+    }
     return(summaries)
 }
 
+#'
+#' @title
+#' Plot Trial Design Summaries
+#'
+#' @description
+#' Generic function to plot a \code{TrialDesignSummaries} object.
+#'
+#' @param x a \code{TrialDesignSummaries} object to plot.
+#' @inheritParams param_grid
+#' @param type The plot type (default = \code{1}). The following plot types are available:
+#' \itemize{
+#'   \item \code{1}: creates a 'Boundaries' plot
+#'   \item \code{3}: creates a 'Stage Levels' plot
+#'   \item \code{4}: creates a 'Error Spending' plot
+#'   \item \code{5}: creates a 'Power and Early Stopping' plot
+#'   \item \code{6}: creates an 'Average Sample Size and Power / Early Stop' plot
+#'   \item \code{7}: creates an 'Power' plot
+#'   \item \code{8}: creates an 'Early Stopping' plot
+#'   \item \code{9}: creates an 'Average Sample Size' plot
+#'   \item \code{"all"}: creates all available plots and returns it as a grid plot or list
+#' }
+#' @param ... further arguments passed to or from other methods.
+#' 
+#' @export
+#'
+plot.TrialDesignSummaries <- function(x, ..., type = 1L, grid = 1) {
+    .assertIsValidPlotType(type, naAllowed = FALSE)
+    .assertIsSingleInteger(grid, "grid", validateType = FALSE)
+    
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("plot")
+    }
+    
+    trialDesignSet <- attr(x, "object")
+    
+    args <- list(
+        x = trialDesignSet,
+        type = type,
+        grid = grid,
+        ...)
+    args$markdown <- markdown
+    
+    if (markdown) {
+        sep <- .getMarkdownPlotPrintSeparator()
+        if (!all(is.na(type)) && length(type) > 1 && grid == 1) {
+            grid <- 0
+        }
+        if (grid > 0) {
+            print(do.call(.plot.TrialDesignSet, args))            
+        } else {
+            do.call(.plot.TrialDesignSet, args)
+        }
+        return(.knitPrintQueue(trialDesignSet, sep = sep, prefix = sep))
+    }
+    
+    plot(trialDesignSet, ...)
+}
+
+#'
+#' @title
+#' Print Trial Design Summaries
+#'
+#' @description
+#' Generic function to print a \code{TrialDesignSummaries} object.
+#'
+#' @param x a \code{TrialDesignSummaries} object to print.
+#' @param ... further arguments passed to or from other methods.
+#' 
+#' @export
+#'
+print.TrialDesignSummaries <- function(x, ...) {
+    attributes(x)[["class"]] <- NULL
+    attributes(x)[["object"]] <- NULL
+    print(x, ...)
+}
+
 #'
 #' @name TrialDesignSet
 #'
@@ -165,60 +259,62 @@ summary.TrialDesignSet <- function(object, ..., type = 1, digits = NA_integer_)
 #'
 #' @importFrom methods new
 #'
-TrialDesignSet <- setRefClass("TrialDesignSet",
-    contains = "FieldSet",
-    fields = list(
-        .plotSettings = "PlotSettings",
-        designs = "list",
-        variedParameters = "character"
-    ),
-    methods = list(
-        #
+TrialDesignSet <- R6::R6Class("TrialDesignSet",
+    inherit = FieldSet,
+    public = list(
+        .plotSettings = NULL,
+        designs = NULL,
+        variedParameters = NULL,
         # @param ... 'designs' OR 'design' and one or more design parameters, e.g., deltaWT = c(0.1, 0.3, 0.4)
-        #
         initialize = function(...) {
-            .plotSettings <<- PlotSettings()
-            designs <<- list()
-            variedParameters <<- character(0)
+            self$.plotSettings <- PlotSettings$new()
+            self$designs <- list()
+            self$variedParameters <- character()
             if (length(list(...)) > 0) {
-                add(...)
+                self$add(...)
             }
-            if (length(designs) > 0) {
-                masterDesign <- designs[[1]]
+            if (length(self$designs) > 0) {
+                masterDesign <- self$designs[[1]]
                 if (inherits(masterDesign, "ParameterSet")) {
-                    .self$.plotSettings <<- masterDesign$.plotSettings
+                    self$.plotSettings <- masterDesign$.plotSettings
                 }
             }
         },
         getPlotSettings = function() {
-            return(.plotSettings)
+            return(self$.plotSettings)
         },
         show = function(showType = 1, digits = NA_integer_) {
-            .show(showType = showType, digits = digits, consoleOutputEnabled = TRUE)
+            self$.show(showType = showType, digits = digits, consoleOutputEnabled = TRUE)
         },
         .show = function(showType = 1, digits = NA_integer_, consoleOutputEnabled = TRUE) {
             "Method for automatically printing trial design sets"
-            .resetCat()
-            .cat("Trial design set with ", length(designs), " designs\n\n",
+            self$.resetCat()
+            self$.cat("Trial design set with ", length(self$designs), " designs\n\n",
                 heading = 1,
                 consoleOutputEnabled = consoleOutputEnabled
             )
-            for (design in designs) {
-                design$.show(showType = showType, consoleOutputEnabled = consoleOutputEnabled)
+            for (design in self$designs) {
+                designOutputLines <- utils::capture.output(design$.show(
+                    showType = showType, consoleOutputEnabled = TRUE))
+                for (designOutputLine in designOutputLines) {
+                    self$.cat(designOutputLine, "\n", 
+                        heading = ifelse(grepl(":$", designOutputLine), 2, 0),
+                        consoleOutputEnabled = consoleOutputEnabled)
+                }
             }
         },
         isEmpty = function() {
-            return(length(designs) == 0)
+            return(length(self$designs) == 0)
         },
         getSize = function() {
-            return(length(designs))
+            return(length(self$designs))
         },
         getDesignMaster = function() {
-            if (length(designs) == 0) {
+            if (length(self$designs) == 0) {
                 stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "no design master defined")
             }
 
-            return(designs[[1]])
+            return(self$designs[[1]])
         },
         .validateDesignsArgument = function(designsToAdd, args) {
             if (!is.list(designsToAdd)) {
@@ -252,7 +348,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 
             varPar <- args[["variedParameters"]]
             if (!is.null(varPar) && length(varPar) > 0) {
-                variedParameters <<- c(variedParameters, varPar)
+                self$variedParameters <- c(self$variedParameters, varPar)
             }
 
             args <- args[!(names(args) %in% c("designs", "variedParameters"))]
@@ -264,20 +360,20 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                 )
             }
 
-            designs <<- c(designs, designsToAddValidated)
+            self$designs <- c(self$designs, designsToAddValidated)
         },
         addVariedParameters = function(varPar) {
             if (is.null(varPar) || !is.character(varPar)) {
                 stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'varPar' must be a valid character vector")
             }
 
-            variedParameters <<- c(variedParameters, varPar)
+            self$variedParameters <- c(self$variedParameters, varPar)
         },
         .validateOptionalArguments = function(...) {
             args <- list(...)
             designsToAdd <- .getOptionalArgument(optionalArgumentName = "designs", ...)
             if (!is.null(designsToAdd)) {
-                .validateDesignsArgument(designsToAdd = designsToAdd, args = args)
+                self$.validateDesignsArgument(designsToAdd = designsToAdd, args = args)
                 return(NULL)
             }
 
@@ -290,8 +386,14 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                     "e.g., deltaWT = c(0.1, 0.3, 0.4)"
                 )
             }
+            
+            if (is.null(design) && length(args) == 1 && .isTrialDesign(args[[1]])) {
+                design <- args[[1]]
+                self$designs <- c(self$designs, design)
+                return(invisible(design))
+            }
 
-            if (is.null(design) && optionalArgumentsDefined && length(designs) == 0) {
+            if (is.null(design) && optionalArgumentsDefined && length(self$designs) == 0) {
                 stop(
                     C_EXCEPTION_TYPE_INCOMPLETE_ARGUMENTS,
                     "at least one design (master) must be defined in this ",
@@ -300,9 +402,9 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
             }
 
             if (!is.null(design)) {
-                designs <<- c(designs, design)
-            } else if (length(designs) > 0) {
-                design <- designs[[1]] # use design master
+                self$designs <- c(self$designs, design)
+            } else if (length(self$designs) > 0) {
+                design <- self$designs[[1]] # use design master
             }
 
             if (!.isTrialDesign(design)) {
@@ -312,20 +414,24 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                 )
             }
 
-            .getArgumentNames(validatedDesign = design, ...)
+            self$.getArgumentNames(validatedDesign = design, ...)
 
-            invisible(design)
+            return(invisible(design))
         },
         .getArgumentNames = function(validatedDesign, ...) {
             args <- list(...)
             if (length(args) == 0) {
-                return(character(0))
+                return(character())
+            }
+            
+            if (length(args) == 1 && .isTrialDesign(args[[1]])) {
+                return("design")
             }
 
             argumentNames <- names(args)
             if (length(argumentNames) == 0) {
                 warning("No argument names available for ", paste(args, collapse = ", "), call. = FALSE)
-                return(character(0))
+                return(character())
             }
 
             argumentNames <- argumentNames[nchar(argumentNames) != 0]
@@ -341,11 +447,11 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                 }
             }
 
-            invisible(argumentNames)
+            return(invisible(argumentNames))
         },
         add = function(...) {
             "Adds 'designs' OR a 'design' and/or a design parameter, e.g., deltaWT = c(0.1, 0.3, 0.4)"
-            design <- .validateOptionalArguments(...)
+            design <- self$.validateOptionalArguments(...)
 
             args <- list(...)
             singleDesign <- args[["singleDesign"]]
@@ -354,17 +460,17 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
             }
 
             if (!is.null(design)) {
-                d <- .createDesignVariants(validatedDesign = design, ...)
-                designs <<- c(designs, d)
+                d <- self$.createDesignVariants(validatedDesign = design, ...)
+                self$designs <- c(self$designs, d)
             }
         },
         assertHaveEqualSidedValues = function() {
-            if (length(designs) == 0) {
+            if (length(self$designs) == 0) {
                 return(invisible())
             }
 
-            sided <- getDesignMaster()$sided
-            for (design in designs) {
+            sided <- self$getDesignMaster()$sided
+            for (design in self$designs) {
                 if (sided != design$sided) {
                     stop(
                         C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS,
@@ -376,12 +482,16 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
         },
         .createDesignVariants = function(validatedDesign, ...) {
             .assertIsTrialDesign(validatedDesign)
-            argumentNames <- .getArgumentNames(validatedDesign = validatedDesign, ...)
+            argumentNames <- self$.getArgumentNames(validatedDesign = validatedDesign, ...)
 
             if (length(argumentNames) == 0) {
                 warning("Creation of design variants stopped: no valid design parameters found", call. = FALSE)
                 return(list())
             }
+            
+            if (identical(argumentNames, "design")) {
+                return(list())
+            }
 
             if (length(argumentNames) > 2) {
                 stop(
@@ -391,7 +501,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                 )
             }
 
-            designVariants <- .createDesignVariantsRecursive(
+            designVariants <- self$.createDesignVariantsRecursive(
                 designMaster = validatedDesign,
                 args = list(...), argumentIndex = 1, argumentNames = argumentNames
             )
@@ -400,11 +510,11 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
         },
         .designSettingExists = function(parameterName, parameterValue, numberOfArguments = 1,
                 parameterNameBefore = NULL, parameterValueBefore = NULL) {
-            if (length(designs) == 0) {
+            if (length(self$designs) == 0) {
                 return(FALSE)
             }
 
-            for (design in designs) {
+            for (design in self$designs) {
                 if (!is.null(parameterNameBefore) && !is.null(parameterValueBefore)) {
                     if (design[[parameterNameBefore]] == parameterValueBefore &&
                             design[[parameterName]] == parameterValue) {
@@ -426,11 +536,11 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 
             designVariants <- list()
             argumentName <- argumentNames[argumentIndex]
-            variedParameters <<- unique(c(variedParameters, argumentName))
+            self$variedParameters <- unique(c(self$variedParameters, argumentName))
             argumentValues <- args[[argumentName]]
 
             for (argumentValue in argumentValues) {
-                if (.designSettingExists(argumentName, argumentValue,
+                if (self$.designSettingExists(argumentName, argumentValue,
                         numberOfArguments = length(argumentNames),
                         parameterNameBefore, parameterValueBefore
                     )) {
@@ -446,7 +556,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                         ), call. = FALSE)
                     }
                 } else {
-                    designMaster2 <- .createDesignVariant(
+                    designMaster2 <- self$.createDesignVariant(
                         designMaster = designMaster,
                         argumentName = argumentName, argumentValue = argumentValue
                     )
@@ -461,7 +571,7 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
                         }
                         designVariants <- c(designVariants, designMaster2)
                     }
-                    designCopies2 <- .createDesignVariantsRecursive(
+                    designCopies2 <- self$.createDesignVariantsRecursive(
                         designMaster = designMaster2,
                         args = args, argumentIndex = argumentIndex + 1, argumentNames = argumentNames,
                         parameterNameBefore = argumentName, parameterValueBefore = argumentValue
@@ -544,42 +654,6 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
     )
 )
 
-#'
-#' @title
-#' Access Trial Design by Index
-#'
-#' @description
-#' Function to the \code{TrialDesign} at position \code{i} in a \code{TrialDesignSet} object.
-#'
-#' @details
-#' Can be used to iterate over all designs in a design set.
-#'
-#' @examples
-#' designSet <- getDesignSet(design = getDesignFisher(), alpha = c(0.01, 0.05))
-#' for (i in 1:length(designSet)) {
-#'     print(designSet[i]$alpha)
-#' }
-#'
-#' @export
-#'
-#' @keywords internal
-#'
-setMethod(
-    "[", "TrialDesignSet",
-    function(x, i, j = NA_character_, ...) {
-        if (length(x$designs) == 0) {
-            return(NULL)
-        }
-
-        design <- x$designs[[i]]
-        if (!missing(j) && !is.na(j) && is.character(j)) {
-            return(design[[j]])
-        }
-
-        return(design)
-    }
-)
-
 #'
 #' @title
 #' Names of a Trial Design Set Object
@@ -595,9 +669,11 @@ setMethod(
 #' @template return_names
 #'
 #' @examples
+#' \dontrun{
 #' designSet <- getDesignSet(design = getDesignGroupSequential(), alpha = c(0.01, 0.05))
 #' names(designSet)
-#'
+#' }
+#' 
 #' @export
 #'
 #' @keywords internal
@@ -622,9 +698,11 @@ names.TrialDesignSet <- function(x) {
 #' representing the number of design in the \code{TrialDesignSet}.
 #'
 #' @examples
+#' \dontrun{
 #' designSet <- getDesignSet(design = getDesignGroupSequential(), alpha = c(0.01, 0.05))
 #' length(designSet)
-#'
+#' }
+#' 
 #' @export
 #'
 #' @keywords internal
@@ -633,6 +711,70 @@ length.TrialDesignSet <- function(x) {
     return(length(x$designs))
 }
 
+.getHarmonizedColumnNames <- function(df1, df2) {
+    colNames1 <- colnames(df1)
+    colNames2 <- colnames(df2)
+    if (length(colNames1) != length(colNames2)) {
+        stop(
+            C_EXCEPTION_TYPE_RUNTIME_ISSUE,
+            "cannot harmonize column names of two data frames if number of columns is unequal (",
+            length(colNames1), " != ", length(colNames2), ")"
+        )
+    }
+
+    colNames <- character()
+    for (i in seq_len(length(colNames1))) {
+        colName1 <- colNames1[i]
+        colName2 <- colNames2[i]
+        if (!identical(colName1, colName2)) {
+            vec1 <- unlist(strsplit(colName1, " "))
+            vec2 <- unlist(strsplit(colName2, " "))
+            colNames <- c(colNames, paste(base::intersect(vec1, vec2), collapse = " "))
+        } else {
+            colNames <- c(colNames, colName1)
+        }
+    }
+    return(colNames)
+}
+
+.insertColumnName <- function(df, colName, colNames, at) {
+    naCol <- rep(NA, nrow(df))
+    if (at == 1) {
+        colNames <- c(colName, colNames)
+        df <- cbind(naCol, df)
+    } else if (at <= length(colNames)) {
+        colNames <- c(colNames[1:(at - 1)], colName, colNames[at:length(colNames)])
+        df <- cbind(df[, 1:(at - 1)], naCol, df[, at:ncol(df)])
+    } else {
+        colNames <- c(colNames, colName)
+        df <- cbind(df, naCol)
+    }
+    colnames(df) <- colNames
+    return(list(df = df, colNames = colNames))
+}
+
+.getHarmonizedDataFrames <- function(df1, df2) {
+    if (ncol(df1) == ncol(df2)) {
+        return(list(df1 = df1, df2 = df2))
+    }
+
+    colNames1 <- colnames(df1)
+    colNames2 <- colnames(df2)
+    difference <- c(colNames1[!(colNames1 %in% colNames2)], colNames2[!(colNames2 %in% colNames1)])
+    for (colName in difference) {
+        if (colName %in% colNames1) {
+            result <- .insertColumnName(df2, colName, colNames2, at = which(colNames1 == colName))
+            colNames2 <- result$colNames
+            df2 <- result$df
+        } else {
+            result <- .insertColumnName(df1, colName, colNames1, at = which(colNames2 == colName))
+            colNames1 <- result$colNames
+            df1 <- result$df
+        }
+    }
+    return(list(df1 = df1, df2 = df2))
+}
+
 #'
 #' @title
 #' Coerce Trial Design Set to a Data Frame
@@ -655,16 +797,23 @@ length.TrialDesignSet <- function(x) {
 #' @template return_dataframe
 #'
 #' @examples
+#' \dontrun{
 #' designSet <- getDesignSet(design = getDesignGroupSequential(), alpha = c(0.01, 0.05))
 #' as.data.frame(designSet)
-#'
+#' }
+#' 
 #' @export
 #'
 #' @keywords internal
 #'
-as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
-        optional = FALSE, niceColumnNamesEnabled = FALSE, includeAllParameters = FALSE,
-        addPowerAndAverageSampleNumber = FALSE, theta = seq(-1, 1, 0.02), nMax = NA_integer_, ...) {
+as.data.frame.TrialDesignSet <- function(x,
+        row.names = NULL,
+        optional = FALSE,
+        niceColumnNamesEnabled = FALSE,
+        includeAllParameters = FALSE,
+        addPowerAndAverageSampleNumber = FALSE,
+        theta = seq(-1, 1, 0.02),
+        nMax = NA_integer_, ...) {
     .assertIsTrialDesignSet(x)
     if (x$isEmpty()) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "cannot create data.frame because the design set is empty")
@@ -698,7 +847,7 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
         if (.isTrialDesignWithValidFutilityBounds(design)) {
             futilityBoundsName <- "futilityBounds"
             if (niceColumnNamesEnabled) {
-                futilityBoundsName <- .getTableColumnNames(design = design)[["futilityBounds"]]
+                futilityBoundsName <- .getParameterCaption("futilityBounds", design, tableOutputEnabled = TRUE)
             }
 
             kMax <- design$kMax
@@ -707,7 +856,7 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
         if (.isTrialDesignWithValidAlpha0Vec(design)) {
             alpha0VecName <- "alpha0Vec"
             if (niceColumnNamesEnabled) {
-                alpha0VecName <- .getTableColumnNames(design = design)[["alpha0Vec"]]
+                alpha0VecName <- .getParameterCaption("alpha0Vec", design, tableOutputEnabled = TRUE)
             }
 
             kMax <- design$kMax
@@ -715,13 +864,14 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
         }
 
         if (addPowerAndAverageSampleNumber) {
-            results <- PowerAndAverageSampleNumberResult(design, theta = theta, nMax = nMax)
+            results <- PowerAndAverageSampleNumberResult$new(design, theta = theta, nMax = nMax)
             suppressWarnings(df2 <- as.data.frame(results,
                 niceColumnNamesEnabled = niceColumnNamesEnabled,
-                includeAllParameters = includeAllParameters
+                includeAllParameters = FALSE
             ))
             df <- merge(df, df2, all.y = TRUE)
         }
+
         if (is.null(dataFrame)) {
             if (niceColumnNamesEnabled) {
                 dataFrame <- cbind("Design number" = rep(1, nrow(df)), df)
@@ -734,6 +884,15 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
             } else {
                 df <- cbind(designNumber = rep(max(dataFrame$designNumber) + 1, nrow(df)), df)
             }
+
+            result <- .getHarmonizedDataFrames(dataFrame, df)
+            dataFrame <- result$df1
+            df <- result$df2
+
+            colNames <- .getHarmonizedColumnNames(dataFrame, df)
+            colnames(dataFrame) <- colNames
+            colnames(df) <- colNames
+
             dataFrame <- rbind(dataFrame, df)
         }
     }
@@ -798,11 +957,80 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
 #'
 #' @export
 #'
-plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
-        xlab = NA_character_, ylab = NA_character_, palette = "Set1",
-        theta = seq(-1, 1, 0.02), nMax = NA_integer_, plotPointsEnabled = NA,
-        legendPosition = NA_integer_, showSource = FALSE,
-        grid = 1, plotSettings = NULL) {
+plot.TrialDesignSet <- function(
+        x, 
+        y, 
+        ..., 
+        type = 1L, 
+        main = NA_character_,
+        xlab = NA_character_, 
+        ylab = NA_character_, 
+        palette = "Set1",
+        theta = seq(-1, 1, 0.02), 
+        nMax = NA_integer_, 
+        plotPointsEnabled = NA,
+        legendPosition = NA_integer_, 
+        showSource = FALSE,
+        grid = 1, 
+        plotSettings = NULL) {
+     
+    .assertIsValidPlotType(type, naAllowed = FALSE)
+    .assertIsSingleInteger(grid, "grid", naAllowed = FALSE, validateType = FALSE)
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("plot")
+    }
+    
+    args <- list(
+        x = x, 
+        y = NULL,
+        type = type,
+        main = main,
+        xlab = xlab,
+        ylab = ylab,
+        palette = palette,
+        theta = theta, 
+        plotPointsEnabled = plotPointsEnabled,
+        legendPosition = legendPosition,
+        showSource = showSource,
+        grid = grid,
+        plotSettings = plotSettings, 
+        ...)
+    
+    if (markdown) {
+        sep <- .getMarkdownPlotPrintSeparator()
+        if (length(type) > 1 && grid == 1) {
+            grid <- 0
+            args$grid <- 0
+        }
+        if (grid > 0) {
+            print(do.call(.plot.TrialDesignSet, args))            
+        } else {
+            do.call(.plot.TrialDesignSet, args)
+        }
+        return(.knitPrintQueue(x, sep = sep, prefix = sep))
+    }
+    
+    return(do.call(.plot.TrialDesignSet, args))
+}
+
+.plot.TrialDesignSet <- function(
+        x, 
+        y, 
+        ..., 
+        type = 1L, 
+        main = NA_character_,
+        xlab = NA_character_, 
+        ylab = NA_character_, 
+        palette = "Set1",
+        theta = seq(-1, 1, 0.02), 
+        nMax = NA_integer_, 
+        plotPointsEnabled = NA,
+        legendPosition = NA_integer_, 
+        showSource = FALSE,
+        grid = 1, 
+        plotSettings = NULL) {
+        
     fCall <- match.call(expand.dots = FALSE)
     designSetName <- deparse(fCall$x)
     .assertGgplotIsInstalled()
@@ -831,7 +1059,7 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
     if (length(typeNumbers) == 1) {
         return(p)
     }
-
+    
     return(.createPlotResultObject(plotList, grid))
 }
 
@@ -841,7 +1069,7 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
         legendPosition = NA_integer_, showSource = FALSE,
         designSetName = NA_character_, plotSettings = NULL) {
     .assertGgplotIsInstalled()
-    if (!is.call(main) && !isS4(main)) {
+    if (!is.call(main) && !.isResultObjectBaseClass(main)) {
         .assertIsSingleCharacter(main, "main", naAllowed = TRUE)
     }
     .assertIsSingleCharacter(xlab, "xlab", naAllowed = TRUE)
@@ -859,7 +1087,7 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
     .assertIsTrialDesign(designMaster)
 
     if (type == 1) {
-        main <- if (!is.call(main) && !isS4(main) && is.na(main)) "Boundaries" else main
+        main <- if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) "Boundaries" else main
         xParameterName <- "informationRates"
         yParameterNames <- "criticalValues"
 
@@ -875,11 +1103,11 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
     } else if (type == 2) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "designs with undefined endpoint do not support plot type 2")
     } else if (type == 3) {
-        main <- if (!is.call(main) && !isS4(main) && is.na(main)) "Stage Levels" else main
+        main <- if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) "Stage Levels" else main
         xParameterName <- "informationRates"
         yParameterNames <- "stageLevels"
     } else if (type == 4) {
-        main <- if (!is.call(main) && !isS4(main) && is.na(main)) "Error Spending" else main
+        main <- if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) "Error Spending" else main
         xParameterName <- "informationRates"
         yParameterNames <- c("alphaSpent")
         if (!.isTrialDesignFisher(designMaster) &&
@@ -889,36 +1117,36 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
         }
         plotPointsEnabled <- ifelse(is.na(plotPointsEnabled), FALSE, plotPointsEnabled)
     } else if (type == 5) {
-        if (!is.call(main) && !isS4(main) && is.na(main)) {
-            main <- PlotSubTitleItems(title = "Power and Early Stopping")
+        if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) {
+            main <- PlotSubTitleItems$new(title = "Power and Early Stopping")
             main$add("N", nMax, "max")
         }
         xParameterName <- "theta"
         yParameterNames <- c("overallEarlyStop", "calculatedPower")
     } else if (type == 6) {
-        if (!is.call(main) && !isS4(main) && is.na(main)) {
-            main <- PlotSubTitleItems(title = "Average Sample Size and Power / Early Stop")
+        if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) {
+            main <- PlotSubTitleItems$new(title = "Average Sample Size and Power / Early Stop")
             main$add("N", nMax, "max")
         }
         xParameterName <- "theta"
         yParameterNames <- c("averageSampleNumber", "overallEarlyStop", "calculatedPower")
     } else if (type == 7) {
-        if (!is.call(main) && !isS4(main) && is.na(main)) {
-            main <- PlotSubTitleItems(title = "Power")
+        if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) {
+            main <- PlotSubTitleItems$new(title = "Power")
             main$add("N", nMax, "max")
         }
         xParameterName <- "theta"
         yParameterNames <- "calculatedPower"
     } else if (type == 8) {
-        if (!is.call(main) && !isS4(main) && is.na(main)) {
-            main <- PlotSubTitleItems(title = "Early Stopping")
+        if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) {
+            main <- PlotSubTitleItems$new(title = "Early Stopping")
             main$add("N", nMax, "max")
         }
         xParameterName <- "theta"
         yParameterNames <- "overallEarlyStop"
     } else if (type == 9) {
-        if (!is.call(main) && !isS4(main) && is.na(main)) {
-            main <- PlotSubTitleItems(title = "Average Sample Size")
+        if (!is.call(main) && !.isResultObjectBaseClass(main) && is.na(main)) {
+            main <- PlotSubTitleItems$new(title = "Average Sample Size")
             main$add("N", nMax, "max")
         }
         xParameterName <- "theta"
@@ -955,23 +1183,33 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
     }
 
     p <- .plotParameterSet(
-        parameterSet = parameterSet, designMaster = designMaster,
+        parameterSet = parameterSet, 
+        designMaster = designMaster,
         xParameterName = xParameterName,
-        yParameterNames = yParameterNames, mainTitle = main, xlab = xlab, ylab = ylab,
-        palette = palette, theta = theta, nMax = nMax, plotPointsEnabled = plotPointsEnabled,
-        legendPosition = legendPosition, plotSettings = plotSettings # , ...
+        yParameterNames = yParameterNames, 
+        mainTitle = main, 
+        xlab = xlab, 
+        ylab = ylab,
+        palette = palette, 
+        theta = theta, 
+        nMax = nMax, 
+        plotPointsEnabled = plotPointsEnabled,
+        legendPosition = legendPosition, 
+        plotSettings = plotSettings
     )
 
-    p <- .addDecistionCriticalValuesToPlot(p = p, designMaster = designMaster, type = type, nMax = nMax)
+    p <- .addDecisionCriticalValuesToPlot(
+        p = p, designMaster = designMaster, 
+        type = type, nMax = nMax)
 
     return(p)
 }
 
-.addDecistionCriticalValuesToPlot <- function(p, designMaster, type, nMax = NA_integer_) {
+.addDecisionCriticalValuesToPlot <- function(p, designMaster, type, nMax = NA_integer_) {
     if (type != 1 || !.isTrialDesignInverseNormalOrGroupSequential(designMaster)) {
         return(p)
     }
-
+    
     data <- as.data.frame(designMaster)
     xyNames <- c("delayedInformationRates", "decisionCriticalValues")
     if (!all(xyNames %in% colnames(data))) {
