@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7133 $
-## |  Last changed: $Date: 2023-06-26 15:57:24 +0200 (Mo, 26 Jun 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -164,7 +164,7 @@ NULL
 
 .getAllAvailableSubsets <- function(numbers, ..., sort = TRUE, digits = NA_integer_) {
     if (length(numbers) == 0) {
-        return(character(0))
+        return(character())
     }
 
     results <- paste0(numbers, collapse = "")
@@ -580,7 +580,7 @@ NULL
 }
 
 .removeDesignFromArgs <- function(args) {
-    for (i in 1:length(args)) {
+    for (i in seq_len(length(args))) {
         if (.isTrialDesign(args[[i]])) {
             return(args[-i])
         }
@@ -596,7 +596,7 @@ NULL
 
     args <- list(...)
     if (length(args) == 0) {
-        return(character(0))
+        return(character())
     }
 
     args <- .removeDesignFromArgs(args)
@@ -655,7 +655,7 @@ NULL
     }
 
     if (length(unknownArgs) > 0) {
-        for (i in 1:length(unknownArgs)) {
+        for (i in seq_len(length(unknownArgs))) {
             unknownArgs[i] <- argNames[argNamesLower == unknownArgs[i]][1]
         }
         if (length(unknownArgs) == 1) {
@@ -683,7 +683,7 @@ NULL
     indices <- gregexpr("[A-Z]", x)[[1]]
     parts <- strsplit(x, "[A-Z]")[[1]]
     result <- ""
-    for (i in 1:length(indices)) {
+    for (i in seq_len(length(indices))) {
         index <- indices[i]
         y <- tolower(substring(x, index, index))
         result <- paste0(result, parts[i], sep, y)
@@ -703,7 +703,7 @@ NULL
         )
     }
     parameterNameVariants <- c(parameterNameVariants, overallParameterNameVariants)
-    otherVariants <- character(0)
+    otherVariants <- character()
     for (parameterNameVariant in parameterNameVariants) {
         otherVariants <- c(otherVariants, .getParameterNameVariant(parameterNameVariant, "."))
         otherVariants <- c(otherVariants, .getParameterNameVariant(parameterNameVariant, "_"))
@@ -854,7 +854,7 @@ getWideFormat <- function(dataInput) {
 .getNumberOfStages <- function(dataFrame, naOmitEnabled = TRUE) {
     if (naOmitEnabled) {
         colNames <- colnames(dataFrame)
-        validColNames <- character(0)
+        validColNames <- character()
         for (colName in colNames) {
             colValues <- dataFrame[, colName]
             if (length(colValues) > 0 && !all(is.na(colValues))) {
@@ -1027,6 +1027,7 @@ getLongFormat <- function(dataInput) {
 #' }
 #'
 #' @examples
+#' \dontrun{
 #' # Absolute information epsilon:
 #' # decision rule 45 >= 46 - 1, i.e., under-running
 #' data <- getDataset(
@@ -1047,6 +1048,7 @@ getLongFormat <- function(dataInput) {
 #' getObservedInformationRates(data,
 #'     maxInformation = 46, informationEpsilon = 0.03
 #' )
+#' }
 #'
 #' @return Returns a list that summarizes the observed information rates.
 #'
