@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7132 $
-## |  Last changed: $Date: 2023-06-26 14:15:08 +0200 (Mon, 26 Jun 2023) $
+## |  File version: $Revision: 8216 $
+## |  Last changed: $Date: 2024-09-16 11:45:02 +0200 (Mo, 16 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -49,7 +49,7 @@ NULL
         if (is.list(x)) {
             return("list()")
         } else if (is.character(x)) {
-            return("character(0)")
+            return("character()")
         } else if (is.integer(x)) {
             return("integer(0)")
         } else if (is.numeric(x)) {
@@ -59,7 +59,7 @@ NULL
         }
     }
 
-    if (is.function(x) || isS4(x)) {
+    if (is.function(x) || .isResultObjectBaseClass(x)) {
         return("NULL")
     }
 
@@ -108,7 +108,7 @@ NULL
         x <- t(x)
     }
 
-    for (i in 1:length(x)) {
+    for (i in seq_len(length(x))) {
         if (nchar(expectedResult) > 0) {
             expectedResult <- paste0(expectedResult, ", ")
         }
@@ -124,16 +124,158 @@ NULL
     return(expectedResult)
 }
 
+.getGeneratorFunctionName <- function(obj) {
+    if ("TrialDesignPlanMeans" == .getClassName(obj)) {
+        if (obj$.isSampleSizeObject()) {
+            return("getSampleSizeMeans")
+        }
+
+        return("getPowerMeans")
+    }
+
+    if ("TrialDesignPlanRates" == .getClassName(obj)) {
+        if (obj$.isSampleSizeObject()) {
+            return("getSampleSizeRates")
+        }
+
+        return("getPowerRates")
+    }
+
+    if ("TrialDesignPlanSurvival" == .getClassName(obj)) {
+        if (obj$.isSampleSizeObject()) {
+            return("getSampleSizeSurvival")
+        }
+
+        return("getPowerSurvival")
+    }
+
+    if ("TrialDesignPlanCountData" == .getClassName(obj)) {
+        if (obj$.isSampleSizeObject()) {
+            return("getSampleSizeCounts")
+        }
+
+        return("getPowerCounts")
+    }
+
+    if (inherits(obj, "TrialDesign")) {
+        return(paste0("get", sub("^Trial", "", .getClassName(obj))))
+    }
+
+    if (inherits(obj, "Dataset")) {
+        return("getDataset")
+    }
+
+    if (inherits(obj, "AnalysisResults")) {
+        return("getAnalysisResults")
+    }
+
+    if ("TrialDesignSet" == .getClassName(obj)) {
+        return("getDesignSet")
+    }
+
+    if ("TrialDesignCharacteristics" == .getClassName(obj)) {
+        return("getDesignCharacteristics")
+    }
+
+    if (inherits(obj, "SimulationResultsMeans")) {
+        return("getSimulationMeans")
+    }
+
+    if (inherits(obj, "SimulationResultsRates")) {
+        return("getSimulationRates")
+    }
+
+    if (inherits(obj, "SimulationResultsSurvival")) {
+        return("getSimulationSurvival")
+    }
+
+    if (inherits(obj, "SimulationResultsCountData")) {
+        return("getSimulationCounts")
+    }
+
+    if (inherits(obj, "SimulationResultsMultiArmMeans")) {
+        return("getSimulationMultiArmMeans")
+    }
+
+    if (inherits(obj, "SimulationResultsMultiArmRates")) {
+        return("getSimulationMultiArmRates")
+    }
+
+    if (inherits(obj, "SimulationResultsMultiArmSurvival")) {
+        return("getSimulationMultiArmSurvival")
+    }
+
+    if (inherits(obj, "SimulationResultsEnrichmentMeans")) {
+        return("getSimulationEnrichmentMeans")
+    }
+
+    if (inherits(obj, "SimulationResultsEnrichmentRates")) {
+        return("getSimulationEnrichmentRates")
+    }
+
+    if (inherits(obj, "SimulationResultsEnrichmentSurvival")) {
+        return("getSimulationEnrichmentSurvival")
+    }
+
+    if (inherits(obj, "PiecewiseSurvivalTime")) {
+        return("getPiecewiseSurvivalTime")
+    }
+
+    if (inherits(obj, "AccrualTime")) {
+        return("getAccrualTime")
+    }
+
+    if (inherits(obj, "StageResults")) {
+        return("getStageResults")
+    }
+
+    if (inherits(obj, "ConditionalPowerResults")) {
+        return("getConditionalPower")
+    }
+
+    if (inherits(obj, "PowerAndAverageSampleNumberResult")) {
+        return("getPowerAndAverageSampleNumber")
+    }
+
+    if (inherits(obj, "EventProbabilities")) {
+        return("getEventProbabilities")
+    }
+
+    if (inherits(obj, "NumberOfSubjects")) {
+        return("getNumberOfSubjects")
+    }
+
+    if (inherits(obj, "PerformanceScore")) {
+        return("gePerformanceScore")
+    }
+
+    if (inherits(obj, "SummaryFactory") || "SummaryFactory" == .getClassName(obj)) {
+        return(.getGeneratorFunctionName(obj$object))
+    }
+
+    stop(
+        C_EXCEPTION_TYPE_RUNTIME_ISSUE,
+        "function '.getGeneratorFunctionName' is not implemented for class ", .getClassName(obj)
+    )
+}
+
 #' @rdname getObjectRCode
 #' @export
-rcmd <- function(obj, ...,
+rcmd <- function(
+        obj, 
+        ...,
         leadingArguments = NULL,
         includeDefaultParameters = FALSE,
         stringWrapParagraphWidth = 90,
         prefix = "",
         postfix = "",
         stringWrapPrefix = "",
-        newArgumentValues = list()) {
+        newArgumentValues = list(),
+        
+        tolerance = 1e-07,
+        pipeOperator = c("auto", "none", "magrittr", "R"),
+        output = c("vector", "cat", "test", "markdown", "internal"),
+        explicitPrint = FALSE) {
     getObjectRCode(
         obj = obj,
         leadingArguments = leadingArguments,
@@ -142,7 +284,11 @@ rcmd <- function(obj, ...,
         prefix = prefix,
         postfix = postfix,
         stringWrapPrefix = stringWrapPrefix,
-        newArgumentValues = newArgumentValues
+        newArgumentValues = newArgumentValues,
+        tolerance = tolerance,
+        pipeOperator = pipeOperator,
+        output = output,
+        explicitPrint = explicitPrint
     )
 }
 
@@ -180,7 +326,9 @@ rcmd <- function(obj, ...,
 #'
 #' @export
 #'
-getObjectRCode <- function(obj, ...,
+getObjectRCode <- function(
+        obj, 
+        ...,
         leadingArguments = NULL,
         includeDefaultParameters = FALSE,
         stringWrapParagraphWidth = 90,
@@ -194,7 +342,7 @@ getObjectRCode <- function(obj, ...,
         explicitPrint = FALSE) {
     functionName <- deparse(substitute(obj))
     functionName <- sub("\\(.*\\)$", "", functionName)
-    
+
     output <- match.arg(output)
 
     .assertIsSingleLogical(includeDefaultParameters, "includeDefaultParameters")
@@ -236,10 +384,7 @@ getObjectRCode <- function(obj, ...,
     }
 
     if (!is.null(obj) && is.function(obj)) {
-        lines <- .getFunctionAsString(obj,
-            stringWrapPrefix = stringWrapPrefix,
-            stringWrapParagraphWidth = stringWrapParagraphWidth
-        )
+        lines <- .getFunctionAsString(obj, stringWrapPrefix = stringWrapPrefix)
         if (length(lines) == 0) {
             return("")
         }
@@ -267,9 +412,9 @@ getObjectRCode <- function(obj, ...,
         )
     }
 
-    precondition <- character(0)
+    precondition <- character()
     if (is.null(leadingArguments)) {
-        leadingArguments <- character(0)
+        leadingArguments <- character()
     }
     if (!inherits(obj, "ConditionalPowerResults") &&
             !is.null(obj[[".design"]]) &&
@@ -409,72 +554,10 @@ getObjectRCode <- function(obj, ...,
             precondition <- c(precond, precondition)
         }
     }
-    
+
     precondition <- unique(precondition)
-    
-    if ("TrialDesignPlanMeans" == .getClassName(obj)) {
-        if (obj$.isSampleSizeObject()) {
-            functionName <- "getSampleSizeMeans"
-        } else {
-            functionName <- "getPowerMeans"
-        }
-    } else if ("TrialDesignPlanRates" == .getClassName(obj)) {
-        if (obj$.isSampleSizeObject()) {
-            functionName <- "getSampleSizeRates"
-        } else {
-            functionName <- "getPowerRates"
-        }
-    } else if ("TrialDesignPlanSurvival" == .getClassName(obj)) {
-        if (obj$.isSampleSizeObject()) {
-            functionName <- "getSampleSizeSurvival"
-        } else {
-            functionName <- "getPowerSurvival"
-        }
-    } else if (inherits(obj, "TrialDesign")) {
-        functionName <- paste0("get", sub("^Trial", "", .getClassName(obj)))
-    } else if (inherits(obj, "Dataset")) {
-        functionName <- "getDataset"
-    } else if (inherits(obj, "AnalysisResults")) {
-        functionName <- "getAnalysisResults"
-    } else if ("TrialDesignSet" == .getClassName(obj)) {
-        functionName <- "getDesignSet"
-    } else if ("TrialDesignCharacteristics" == .getClassName(obj)) {
-        functionName <- "getDesignCharacteristics"
-    } else if (inherits(obj, "SimulationResultsMeans")) {
-        functionName <- "getSimulationMeans"
-    } else if (inherits(obj, "SimulationResultsRates")) {
-        functionName <- "getSimulationRates"
-    } else if (inherits(obj, "SimulationResultsSurvival")) {
-        functionName <- "getSimulationSurvival"
-    } else if (inherits(obj, "SimulationResultsMultiArmMeans")) {
-        functionName <- "getSimulationMultiArmMeans"
-    } else if (inherits(obj, "SimulationResultsMultiArmRates")) {
-        functionName <- "getSimulationMultiArmRates"
-    } else if (inherits(obj, "SimulationResultsMultiArmSurvival")) {
-        functionName <- "getSimulationMultiArmSurvival"
-    } else if (inherits(obj, "SimulationResultsEnrichmentMeans")) {
-        functionName <- "getSimulationEnrichmentMeans"
-    } else if (inherits(obj, "SimulationResultsEnrichmentRates")) {
-        functionName <- "getSimulationEnrichmentRates"
-    } else if (inherits(obj, "SimulationResultsEnrichmentSurvival")) {
-        functionName <- "getSimulationEnrichmentSurvival"
-    } else if (inherits(obj, "PiecewiseSurvivalTime")) {
-        functionName <- "getPiecewiseSurvivalTime"
-    } else if (inherits(obj, "AccrualTime")) {
-        functionName <- "getAccrualTime"
-    } else if (inherits(obj, "StageResults")) {
-        functionName <- "getStageResults"
-    } else if (inherits(obj, "ConditionalPowerResults")) {
-        functionName <- "getConditionalPower"
-    } else if (inherits(obj, "PowerAndAverageSampleNumberResult")) {
-        functionName <- "getPowerAndAverageSampleNumber"
-    } else if (inherits(obj, "EventProbabilities")) {
-        functionName <- "getEventProbabilities"
-    } else if (inherits(obj, "NumberOfSubjects")) {
-        functionName <- "getNumberOfSubjects"
-    } else if (inherits(obj, "PerformanceScore")) {
-        functionName <- "gePerformanceScore"
-    } else if (inherits(obj, "SummaryFactory") || "SummaryFactory" == .getClassName(obj)) {
+
+    if (inherits(obj, "SummaryFactory") || "SummaryFactory" == .getClassName(obj)) {
         return(getObjectRCode(obj$object,
             prefix = ifelse(pipeOperator == "none", "summary(", ""),
             postfix = {
@@ -489,7 +572,7 @@ getObjectRCode <- function(obj, ...,
             explicitPrint = explicitPrint
         ))
     } else {
-        stop("Runtime issue: function 'getObjectRCode' is not implemented for class ", .getClassName(obj))
+        functionName <- .getGeneratorFunctionName(obj)
     }
 
     objNames <- names(obj)
@@ -551,9 +634,10 @@ getObjectRCode <- function(obj, ...,
     if (!("accrualIntensity" %in% objNames) && !is.null(obj[[".accrualTime"]]) &&
             !obj$.accrualTime$absoluteAccrualIntensityEnabled) {
         objNames <- c(objNames, "accrualIntensity")
+        objNames <- objNames[objNames != "accrualIntensityRelative"]
     }
 
-    newArgumentValueNames <- character(0)
+    newArgumentValueNames <- character()
     if (length(newArgumentValues) > 0) {
         newArgumentValueNames <- names(newArgumentValues)
         illegalArgumentValueNames <- newArgumentValueNames[which(!(newArgumentValueNames %in% names(obj)))]
@@ -769,23 +853,28 @@ getObjectRCode <- function(obj, ...,
             length(stringWrapPrefix) == 1 &&
             !is.na(stringWrapPrefix) &&
             is.character(stringWrapPrefix)) {
-        rCodeNew <- character(0)
+        rCodeNew <- character()
         for (rCodeLine in rCode) {
-            rCodeLine <- gsub("   ", "___", rCodeLine)
-            rCodeLine <- gsub("  ", "__", rCodeLine)
-            rCodeLines <- strwrap(rCodeLine, width = stringWrapParagraphWidth)
+            for (i in 12:2) {
+                rCodeLine <- gsub(paste(rep(" ", i), collapse = ""), 
+                    paste(rep("_", i), collapse = ""), rCodeLine)
+            }
+            rCodeLines <- strwrap(rCodeLine, width = stringWrapParagraphWidth - 2)
             if (length(rCodeLines) > 1) {
                 for (i in 2:length(rCodeLines)) {
                     if (grepl("^ *(\\|>|%>%) *", rCodeLines[i])) {
                         rCodeLines[i - 1] <- paste0(rCodeLines[i - 1], pipeOperatorPostfix)
                         rCodeLines[i] <- sub("^ *(\\|>|%>%) *", "", rCodeLines[i])
-                    } else if (!grepl("^ *([a-zA-Z0-9]+ *<-)|(^ *get[a-zA-Z]+\\()|summary\\(", rCodeLines[i])) {
+                    } else if (!grepl("^ *([a-zA-Z0-9]+ *<-)|(^ *get[a-zA-Z]+\\()|summary\\(", 
+                            rCodeLines[i])) {
                         rCodeLines[i] <- paste0(stringWrapPrefix, rCodeLines[i])
                     }
                 }
             }
-            rCodeLines <- gsub("___", "   ", rCodeLines)
-            rCodeLines <- gsub("__", "  ", rCodeLines)
+            for (i in 12:2) {
+                rCodeLines <- gsub(paste(rep("_", i), collapse = ""), 
+                    paste(rep(" ", i), collapse = ""), rCodeLines)
+            }
             rCodeLines <- rCodeLines[nchar(trimws(rCodeLines)) > 0]
             rCodeNew <- c(rCodeNew, rCodeLines)
         }
@@ -811,9 +900,6 @@ getObjectRCode <- function(obj, ...,
             collapse <- paste0("\n", stringWrapPrefix)
             if (explicitPrint) {
                 rCode <- gsub("print\\(\\)", "print(markdown = TRUE)", rCode)
-            } else if (!any(grepl("kable\\(", rCode))) {
-                rCode[length(rCode)] <- paste0(rCode[length(rCode)], pipeOperatorPostfix)
-                rCode <- c(rCode, "kable()")
             }
         }
 
