@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5924 $
-## |  Last changed: $Date: 2022-03-04 10:48:37 +0100 (Fri, 04 Mar 2022) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -46,6 +46,13 @@ NULL
 }
 
 .getMatrixFormatted <- function(paramValueFormatted, enforceListOuput = FALSE) {
+    if (length(paramValueFormatted) == 0) {
+        return(list(
+            paramValueFormatted = matrix(nrow = 0, ncol = 0),
+            type = "matrix"
+        ))
+    }
+
     if (!is.matrix(paramValueFormatted) && enforceListOuput) {
         paramValueFormatted <- matrix(paramValueFormatted, nrow = 1)
     }
@@ -84,7 +91,7 @@ NULL
             parameterName <- result$parameterName
             paramValue <- result$paramValue
 
-            if (isS4(paramValue)) {
+            if (.isResultObjectBaseClass(paramValue)) {
                 return(NULL)
             }
 
@@ -136,7 +143,7 @@ NULL
                     paramValueFormatted <- C_TYPE_OF_DESIGN_BS_LIST[[paramValue]]
                 }
             } else {
-                formatFunctionName <- obj$.parameterFormatFunctions[[parameterName]]
+                formatFunctionName <- .getParameterFormatFunction(parameterName, obj)
                 if (!is.null(formatFunctionName)) {
                     paramValueFormatted <- eval(call(formatFunctionName, paramValueFormatted))
                     if (.isArray(paramValue) && length(dim(paramValue)) == 2) {
