@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 7961 $
+## |  Last changed: $Date: 2024-05-30 14:58:05 +0200 (Thu, 30 May 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -22,13 +22,29 @@
 NULL
 
 # See testthat::skip_on_cran()
-.skipTestIfDisabled <- function() {
+.skipTestIfDisabled <- function(msg = "Test is disabled", ..., ignoreInTestPlan = FALSE) {
     if (!isTRUE(.isCompleteUnitTestSetEnabled()) &&
             base::requireNamespace("testthat", quietly = TRUE)) {
-        testthat::skip("Test is disabled")
+        if (isTRUE(ignoreInTestPlan)) {
+            msg <- paste(msg, "and ignored in test plan")
+        }
+        testthat::skip(msg)
     }
 }
 
+.skipTestIfCppCompilerIsMissing <- function() {
+    if (.Platform$OS.type != "windows") {
+        return(invisible())
+    }
+
+    if (.isPackageInstalled("pkgbuild") &&
+            isTRUE(eval(parse(text = "pkgbuild::has_build_tools(debug = FALSE)")))) {
+        return(invisible())
+    }
+
+    testthat::skip("The test requires a C++ compiler")
+}
+
 .skipTestIfNotX64 <- function() {
     if (!.isMachine64Bit() && !.isMinimumRVersion4() && base::requireNamespace("testthat", quietly = TRUE)) {
         testthat::skip("The test is only intended for R version 4.x or 64-bit computers (x86-64)")
@@ -37,7 +53,10 @@ NULL
 
 .skipTestIfPipeOperatorNotAvailable <- function() {
     if (!.isPipeOperatorAvailable()) {
-        testthat::skip("The test is disabled because it works only for R version >= 4.1.0 (pipe operator is available)")
+        testthat::skip(paste0(
+            "The test is disabled because it works only for ",
+            "R version >= 4.1.0 (pipe operator is available)"
+        ))
     }
 }
 
@@ -195,7 +214,10 @@ NULL
             for (testFile in testFiles) {
                 file.copy(file.path(testthatTempSubDirectory, testFile), file.path(testFileTargetDirectory, testFile))
             }
-            message(length(testFiles), " extracted from ", sQuote(packageSource), " and copied to ", sQuote(testFileTargetDirectory))
+            message(
+                length(testFiles), " extracted from ", sQuote(packageSource),
+                " and copied to ", sQuote(testFileTargetDirectory)
+            )
         },
         finally = {
             if (!is.null(testthatTempDirectory)) {
@@ -214,7 +236,7 @@ NULL
     tryCatch(
         {
             version <- utils::packageVersion("rpact")
-            baseUrl <- paste0("http://", token, ":", secret, "@unit.tests.rpact.com/", version, "/tests/")
+            baseUrl <- paste0("https://", token, ":", secret, "@unit.tests.rpact.com/", version, "/tests/")
 
             if (!dir.exists(testFileTargetDirectory)) {
                 dir.create(testFileTargetDirectory)
@@ -228,7 +250,7 @@ NULL
                 file.copy(testthatBaseFile, file.path(testFileTargetDirectory, "testthat.R"))
             } else {
                 currentFile <- "testthat.R"
-                result <- download.file(
+                result <- utils::download.file(
                     url = paste0(baseUrl, "testthat.R"),
                     destfile = file.path(testFileTargetDirectory, "testthat.R"),
                     method = "auto", mode = "wb"
@@ -239,7 +261,7 @@ NULL
             }
 
             currentFile <- "index.txt"
-            result <- download.file(
+            result <- utils::download.file(
                 url = paste0(baseUrl, "testthat/index.txt"),
                 destfile = indexFile, quiet = TRUE,
                 method = "auto", mode = "wb"
@@ -264,7 +286,7 @@ NULL
             message("Start to download ", length(testFiles), " unit test files (http). Please wait...")
             for (testFile in testFiles) {
                 currentFile <- testFile
-                result <- download.file(
+                result <- utils::download.file(
                     url = paste0(baseUrl, "testthat/", testFile),
                     destfile = file.path(testthatSubDirectory, testFile), quiet = TRUE,
                     method = "auto", mode = "wb"
@@ -290,7 +312,8 @@ NULL
             .logDebug(e$message)
             stop(
                 C_EXCEPTION_TYPE_RUNTIME_ISSUE,
-                "failed to download unit test files (http): illegal 'token' / 'secret' or rpact version ", version, " unknown"
+                "failed to download unit test files (http): ",
+                "illegal 'token' / 'secret' or rpact version ", version, " unknown"
             )
         },
         finally = {
@@ -373,7 +396,8 @@ NULL
             .logDebug(e$message)
             stop(
                 C_EXCEPTION_TYPE_RUNTIME_ISSUE,
-                "failed to download unit test files (ftp): illegal 'token' / 'secret' or rpact version ", version, " unknown"
+                "failed to download unit test files (ftp): ",
+                "illegal 'token' / 'secret' or rpact version ", version, " unknown"
             )
         },
         finally = {
@@ -396,7 +420,10 @@ NULL
             "mode", "cacheEnabled", "extra", "cleanOldFiles", "connectionType"
         )) {
     if (is.null(connection) || !is.list(connection)) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'connection' must be a list (is ", .getClassName(connection), ")")
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "'connection' must be a list (is ", .getClassName(connection), ")"
+        )
     }
 
     name <- match.arg(name)
@@ -459,7 +486,6 @@ testPackage <- function(outDir = ".", ...,
         types = "tests",
         connection = list(token = NULL, secret = NULL)) {
     .assertTestthatIsInstalled()
-    .assertMnormtIsInstalled()
 
     .assertIsSingleCharacter(outDir, "outDir", naAllowed = FALSE)
     if (!dir.exists(outDir)) {
@@ -494,7 +520,7 @@ testPackage <- function(outDir = ".", ...,
 
     if (completeUnitTestSetEnabled && fullTestEnabled) {
         cat("Run all tests. Please wait...\n")
-        cat("Have a break - it takes about 15 minutes.\n")
+        cat("Have a break - it takes about 20 minutes.\n")
         cat("Exceution of all available unit tests startet at ",
             format(startTime, "%H:%M (%d-%B-%Y)"), "\n",
             sep = ""
@@ -556,7 +582,9 @@ testPackage <- function(outDir = ".", ...,
         )
     }
 
-    cat("Total runtime for testing: ", .getRuntimeString(startTime, endTime = endTime, runtimeUnits = "auto"), ".\n", sep = "")
+    cat("Total runtime for testing: ", .getRuntimeString(startTime,
+        endTime = endTime, runtimeUnits = "auto"
+    ), ".\n", sep = "")
 
     inputFileName <- file.path(outDir, "testthat.Rout")
     if (file.exists(inputFileName)) {
