@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7206 $
-## |  Last changed: $Date: 2023-07-25 14:55:05 +0200 (Tue, 25 Jul 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -69,9 +69,13 @@ NULL
     return(selectedVector)
 }
 
-
-.selectPopulations <- function(stage, effectVector, typeOfSelection,
-        epsilonValue, rValue, threshold, selectPopulationsFunction) {
+.selectPopulations <- function(typeOfSelection,
+        epsilonValue,
+        rValue,
+        threshold,
+        selectPopulationsFunction,
+        selectPopulationsFunctionArgs) {
+    effectVector <- selectPopulationsFunctionArgs$effectVector
     gMax <- length(effectVector)
 
     if (typeOfSelection != "userDefined") {
@@ -92,26 +96,20 @@ NULL
         selectedPopulations[effectVector <= threshold] <- FALSE
     } else {
         functionArgumentNames <- .getFunctionArgumentNames(selectPopulationsFunction, ignoreThreeDots = TRUE)
-        if (length(functionArgumentNames) == 1) {
-            .assertIsValidFunction(
-                fun = selectPopulationsFunction,
-                funArgName = "selectPopulationsFunction",
-                expectedArguments = c("effectVector"), validateThreeDots = FALSE
-            )
-            selectedPopulations <- selectPopulationsFunction(effectVector)
-        } else {
-            .assertIsValidFunction(
-                fun = selectPopulationsFunction,
-                funArgName = "selectPopulationsFunction",
-                expectedArguments = c("effectVector", "stage"), validateThreeDots = FALSE
-            )
-            selectedPopulations <- selectPopulationsFunction(effectVector = effectVector, stage = stage)
-        }
+        .assertIsValidFunction(
+            fun = selectPopulationsFunction,
+            funArgName = "selectPopulationsFunction",
+            expectedArguments = names(selectPopulationsFunctionArgs),
+            validateThreeDots = FALSE
+        )
+        selectedPopulations <- do.call(what = selectPopulationsFunction, 
+            args = selectPopulationsFunctionArgs[functionArgumentNames])
         selectedPopulations[is.na(effectVector)] <- FALSE
 
         msg <- paste0(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "'selectPopulationsFunction' returned an illegal or undefined result (", .arrayToString(selectedPopulations), "); "
+            "'selectPopulationsFunction' returned an illegal or undefined result (", 
+            .arrayToString(selectedPopulations), "); "
         )
         if (length(selectedPopulations) != gMax) {
             stop(msg, "the output must be a logical vector of length 'gMax' (", gMax, ")")
@@ -159,7 +157,7 @@ NULL
     separatePValues <- stageResults$separatePValues
     if (intersectionTest == "SpiessensDebois") {
         subjectsPerStage <- stageResults[[ifelse(
-            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "eventsPerStage"
+            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "cumulativeEventsPerStage"
         )]]
         testStatistics <- stageResults$testStatistics
     } else {
@@ -219,13 +217,14 @@ NULL
                 }
             }
 
+            criticalValues <- .getCriticalValues(design)
             if (.isTrialDesignFisher(design)) {
-                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= design$criticalValues[k])
+                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= criticalValues[k])
                 if (k < kMax) {
                     futilityIntersections[i, k] <- (adjustedStageWisePValues[i, k] >= design$alpha0Vec[k])
                 }
             } else if (.isTrialDesignInverseNormal(design)) {
-                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] >= design$criticalValues[k])
+                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] >= criticalValues[k])
                 if (k < kMax) {
                     futilityIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= design$futilityBounds[k])
                 }
@@ -256,7 +255,7 @@ NULL
 
         if (k < kMax) {
             futilityStop[k] <- all(futility[stageResults$selectedPopulations[1:gMax, k], k])
-            if (all(isFALSE(stageResults$selectedPopulations[1:gMax, k + 1]))) {
+            if (all(!stageResults$selectedPopulations[1:gMax, k + 1], na.rm = TRUE)) {
                 futilityStop[k] <- TRUE
             }
         }
@@ -351,11 +350,11 @@ NULL
     effectMeasure <- .assertIsValidEffectMeasure(effectMeasure)
 
     if (endpoint == "means") {
-        simulationResults <- SimulationResultsEnrichmentMeans(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsEnrichmentMeans$new(design, showStatistics = showStatistics)
     } else if (endpoint == "rates") {
-        simulationResults <- SimulationResultsEnrichmentRates(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsEnrichmentRates$new(design, showStatistics = showStatistics)
     } else if (endpoint == "survival") {
-        simulationResults <- SimulationResultsEnrichmentSurvival(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsEnrichmentSurvival$new(design, showStatistics = showStatistics)
     }
 
     effectList <- .getValidatedEffectList(effectList, endpoint = endpoint)
@@ -449,24 +448,6 @@ NULL
         )
     }
 
-    if (endpoint == "means") {
-        # 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(thetaH1)) {
-        # 			warning("'thetaH1' will be ignored because neither 'conditionalPower' nor ",
-        # 				"'calcSubjectsFunction' is defined", call. = FALSE)
-        # 		}
-        # 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(stDevH1)) {
-        # 			warning("'stDevH1' will be ignored because neither 'conditionalPower' nor ",
-        # 				"'calcSubjectsFunction' is defined", call. = FALSE)
-        # 		}
-    }
-
-    if (endpoint == "survival") {
-        # 		if (is.na(conditionalPower) && is.null(calcEventsFunction) && !is.na(thetaH1)) {
-        # 			warning("'thetaH1' will be ignored because neither 'conditionalPower' nor ",
-        # 				"'calcEventsFunction' is defined", call. = FALSE)
-        # 		}
-    }
-
     conditionalPower <- .ignoreParameterIfNotUsed(
         "conditionalPower",
         conditionalPower, kMax > 1, "design is fixed ('kMax' = 1)"
@@ -745,7 +726,5 @@ NULL
     .setValueAndParameterType(simulationResults, "successCriterion", successCriterion, C_SUCCESS_CRITERION_DEFAULT)
     .setValueAndParameterType(simulationResults, "effectMeasure", effectMeasure, C_EFFECT_MEASURE_DEFAULT)
 
-    warning("Simulation of enrichment designs is experimental and hence not fully validated (see www.rpact.com/experimental)", call. = FALSE)
-
     return(simulationResults)
 }
