@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -252,6 +252,7 @@ NULL
 
         separatePValues[, k] <- 1 - stats::pnorm(testStatistics[, k])
 
+        criticalValues <- .getCriticalValues(design)
         if (k < kMax) {
             if (colSums(selectedPopulations)[k] == 0) {
                 break
@@ -259,32 +260,49 @@ NULL
 
             # Bonferroni adjustment
             adjustedPValues[k] <- min(min(separatePValues[, k], na.rm = TRUE) *
-                colSums(selectedPopulations)[k], 1 - 1e-7)
+                colSums(selectedPopulations)[k], 1 - 1e-07)
 
             # conditional critical value to reject the null hypotheses at the next stage of the trial
             if (.isTrialDesignFisher(design)) {
-                conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                    prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-7))
+                conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
+                    prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
             } else {
-                conditionalCriticalValue[k] <- (design$criticalValues[k + 1] *
+                conditionalCriticalValue[k] <- (criticalValues[k + 1] *
                     sqrt(design$informationRates[k + 1]) -
                     .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                     sqrt(design$informationRates[k + 1] - design$informationRates[k])
             }
 
             if (adaptations[k]) {
+                selectPopulationsFunctionArgs <- list(
+                    effectVector = NULL,
+                    stage = k,
+                    conditionalPower = conditionalPower,
+                    conditionalCriticalValue = conditionalCriticalValue,
+                    plannedSubjects = plannedSubjects,
+                    allocationRatioPlanned = allocationRatioPlanned,
+                    selectedPopulations = selectedPopulations,
+                    thetaH1 = thetaH1,
+                    stDevH1 = stDevH1,
+                    overallEffects = overallEffects
+                )
                 if (effectMeasure == "testStatistic") {
-                    selectedPopulations[, k + 1] <- (selectedPopulations[, k] & .selectPopulations(
-                        k, overallTestStatistics[, k],
-                        typeOfSelection, epsilonValue, rValue, threshold, selectPopulationsFunction
-                    ))
+                    selectPopulationsFunctionArgs$effectVector <- overallTestStatistics[, k]
                 } else if (effectMeasure == "effectEstimate") {
-                    selectedPopulations[, k + 1] <- (selectedPopulations[, k] & .selectPopulations(
-                        k, overallEffects[, k],
-                        typeOfSelection, epsilonValue, rValue, threshold, selectPopulationsFunction
-                    ))
+                    selectPopulationsFunctionArgs$effectVector <- overallEffects[, k]
                 }
 
+                args <- list(
+                    typeOfSelection = typeOfSelection,
+                    epsilonValue = epsilonValue,
+                    rValue = rValue,
+                    threshold = threshold,
+                    selectPopulationsFunction = selectPopulationsFunction,
+                    selectPopulationsFunctionArgs = selectPopulationsFunctionArgs
+                )
+
+                selectedPopulations[, k + 1] <- (selectedPopulations[, k] & do.call(.selectPopulations, args))
+
                 newSubjects <- calcSubjectsFunction(
                     stage = k + 1, # to be consistent with non-enrichment situation, cf. line 36
                     conditionalPower = conditionalPower,
