@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -61,7 +61,7 @@ NULL
                     sqrt(pim * (1 - pim) * (1 + allocationRatioPlanned[stage])) +
                     .getQNorm(conditionalPower) * sqrt(pi1H1 * (1 - pi1H1) +
                         pi2H1 * (1 - pi2H1) * allocationRatioPlanned[stage]), na.rm = TRUE))^2 /
-                    (max(1e-7, (2 * directionUpper - 1) * (pi1H1 - pi2H1), na.rm = TRUE))^2
+                    (max(1e-07, (2 * directionUpper - 1) * (pi1H1 - pi2H1), na.rm = TRUE))^2
 
                 newSubjects <- min(
                     max(minNumberOfSubjectsPerStage[stage + 1], newSubjects),
@@ -169,7 +169,6 @@ NULL
             round(subjectsPerStage[selsubs, k] / (1 + const)), piControls[selsubs]
         )
 
-
         if (gMax == 1) {
             rm <- (simEventsControl[1, k] + simEventsTreatment[1, k]) / subjectsPerStage[1, k]
             if (rm <= 0 || rm >= 1) {
@@ -195,6 +194,7 @@ NULL
                     sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[1, 1:k]) * const / (1 + const)^2)
             }
         } else if (gMax == 2) {
+            
             # Population S1
             rm <- (simEventsControl[1, k] + simEventsTreatment[1, k]) / subjectsPerStage[1, k]
             if (!is.na(rm)) {
@@ -223,6 +223,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[1, 1:k]) * const / (1 + const)^2)
                 }
             }
+            
             # Full population
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[1:2, k] + simEventsTreatment[1:2, k]) / subjectsPerStage[1:2, k]
@@ -271,6 +272,7 @@ NULL
                 }
             }
         } else if (gMax == 3) {
+            
             # Population S1
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[c(1, 3), k] + simEventsTreatment[c(1, 3), k]) / subjectsPerStage[c(1, 3), k]
@@ -318,6 +320,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE) * const / (1 + const)^2)
                 }
             }
+            
             # Population S2
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[c(2, 3), k] + simEventsTreatment[c(2, 3), k]) / subjectsPerStage[c(2, 3), k]
@@ -365,6 +368,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE) * const / (1 + const)^2)
                 }
             }
+            
             # Full population
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[1:4, k] + simEventsTreatment[1:4, k]) / subjectsPerStage[1:4, k]
@@ -413,6 +417,7 @@ NULL
                 }
             }
         } else if (gMax == 4) {
+            
             # Population S1
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[c(1, 4, 5, 7), k] + simEventsTreatment[c(1, 4, 5, 7), k]) / subjectsPerStage[c(1, 4, 5, 7), k]
@@ -460,6 +465,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE) * const / (1 + const)^2)
                 }
             }
+            
             # Population S2
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[c(2, 4, 6, 7), k] + simEventsTreatment[c(2, 4, 6, 7), k]) / subjectsPerStage[c(2, 4, 6, 7), k]
@@ -507,6 +513,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE) * const / (1 + const)^2)
                 }
             }
+            
             # Population S3
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[c(3, 5, 6, 7), k] + simEventsTreatment[c(3, 5, 6, 7), k]) / subjectsPerStage[c(3, 5, 6, 7), k]
@@ -554,6 +561,7 @@ NULL
                         sqrt(rm * (1 - rm)) * sqrt(sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE) * const / (1 + const)^2)
                 }
             }
+            
             # Full population
             if (stratifiedAnalysis) {
                 rm <- (simEventsControl[1:8, k] + simEventsTreatment[1:8, k]) / subjectsPerStage[1:8, k]
@@ -609,6 +617,7 @@ NULL
 
         separatePValues[, k] <- 1 - stats::pnorm(testStatistics[, k])
 
+        criticalValues <- .getCriticalValues(design)
         if (k < kMax) {
             if (colSums(selectedPopulations)[k] == 0) {
                 break
@@ -620,33 +629,50 @@ NULL
 
             # conditional critical value to reject the null hypotheses at the next stage of the trial
             if (.isTrialDesignFisher(design)) {
-                conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                    prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-7))
+                conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
+                    prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
             } else {
-                if (design$criticalValues[k + 1] >= 6) {
+                if (criticalValues[k + 1] >= 6) {
                     conditionalCriticalValue[k] <- Inf
                 } else {
-                    conditionalCriticalValue[k] <- (design$criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
+                    conditionalCriticalValue[k] <- (criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
                         .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                         sqrt(design$informationRates[k + 1] - design$informationRates[k])
                 }
             }
 
             if (adaptations[k]) {
+                selectPopulationsFunctionArgs <- list(
+                    effectVector = NULL,
+                    stage = k,
+                    directionUpper = directionUpper,
+                    conditionalPower = conditionalPower,
+                    conditionalCriticalValue = conditionalCriticalValue,
+                    plannedSubjects = plannedSubjects,
+                    allocationRatioPlanned = allocationRatioPlanned,
+                    selectedPopulations = selectedPopulations,
+                    piTreatmentH1 = piTreatmentH1,
+                    piControlH1 = piControlH1,
+                    overallRatesTreatment = overallRatesTreatment,
+                    overallRatesControl = overallRatesControl
+                )
                 if (effectMeasure == "testStatistic") {
-                    selectedPopulations[, k + 1] <- (selectedPopulations[, k] &
-                        .selectPopulations(
-                            k, overallTestStatistics[, k] + runif(gMax, -1e-05, 1e-05),
-                            typeOfSelection, epsilonValue, rValue, threshold, selectPopulationsFunction
-                        ))
+                    selectPopulationsFunctionArgs$effectVector <- overallTestStatistics[, k] + runif(gMax, -1e-05, 1e-05)
                 } else if (effectMeasure == "effectEstimate") {
-                    selectedPopulations[, k + 1] <- (selectedPopulations[, k] &
-                        .selectPopulations(
-                            k, overallEffectSizes[, k] + runif(gMax, -1e-05, 1e-05),
-                            typeOfSelection, epsilonValue, rValue, threshold, selectPopulationsFunction
-                        ))
+                    selectPopulationsFunctionArgs$effectVector <- overallEffectSizes[, k] + runif(gMax, -1e-05, 1e-05)
                 }
 
+                args <- list(
+                    typeOfSelection = typeOfSelection,
+                    epsilonValue = epsilonValue,
+                    rValue = rValue,
+                    threshold = threshold,
+                    selectPopulationsFunction = selectPopulationsFunction,
+                    selectPopulationsFunctionArgs = selectPopulationsFunctionArgs
+                )
+
+                selectedPopulations[, k + 1] <- (selectedPopulations[, k] & do.call(.selectPopulations, args))
+
                 newSubjects <- calcSubjectsFunction(
                     stage = k + 1, # to be consistent with non-enrichment situation, cf. line 40
                     directionUpper = directionUpper,
@@ -707,10 +733,13 @@ NULL
 
             thetaStandardized <- (2 * directionUpper - 1) * thetaStandardized
 
-            thetaStandardized <- min(thetaStandardized, na.rm = TRUE)
-
-            conditionalPowerPerStage[k] <- 1 - stats::pnorm(conditionalCriticalValue[k] -
-                thetaStandardized * sqrt(plannedSubjects[k + 1] - plannedSubjects[k]))
+            if (any(!is.na(thetaStandardized))) {
+                thetaStandardized <- min(thetaStandardized, na.rm = TRUE)
+                conditionalPowerPerStage[k] <- 1 - stats::pnorm(conditionalCriticalValue[k] -
+                    thetaStandardized * sqrt(plannedSubjects[k + 1] - plannedSubjects[k]))
+            } else {
+                conditionalPowerPerStage[k] <- 0
+            }
         }
     }
     return(list(
@@ -810,7 +839,7 @@ getSimulationEnrichmentRates <- function(design = NULL, ...,
         effectList = NULL,
         intersectionTest = c("Simes", "SpiessensDebois", "Bonferroni", "Sidak"), # C_INTERSECTION_TEST_ENRICHMENT_DEFAULT
         stratifiedAnalysis = TRUE, # C_STRATIFIED_ANALYSIS_DEFAULT,
-        directionUpper = TRUE, # C_DIRECTION_UPPER_DEFAULT
+        directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         adaptations = NA,
         typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
         effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
@@ -849,6 +878,9 @@ getSimulationEnrichmentRates <- function(design = NULL, ...,
 
     calcSubjectsFunctionIsUserDefined <- !is.null(calcSubjectsFunction)
 
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
+        design, objectType = "power", userFunctionCallEnabled = TRUE)
+    
     simulationResults <- .createSimulationResultsEnrichmentObject(
         design = design,
         effectList = effectList,
