@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -137,7 +137,7 @@ NULL
 
             # Bonferroni adjustment
             adjustedPValues[k] <- min(min(separatePValues[, k], na.rm = TRUE) *
-                (colSums(selectedArms)[k] - 1), 1 - 1e-7)
+                (colSums(selectedArms)[k] - 1), 1 - 1e-07)
 
             # conditional critical value to reject the null hypotheses at the next stage of the trial
             if (.isTrialDesignConditionalDunnett(design)) {
@@ -145,11 +145,12 @@ NULL
                     .getOneMinusQNorm(adjustedPValues[k]) * sqrt(design$informationAtInterim)) /
                     sqrt(1 - design$informationAtInterim)
             } else {
+                criticalValues <- .getCriticalValues(design)
                 if (.isTrialDesignFisher(design)) {
-                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-7))
+                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
+                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
                 } else {
-                    conditionalCriticalValue[k] <- (design$criticalValues[k + 1] *
+                    conditionalCriticalValue[k] <- (criticalValues[k + 1] *
                         sqrt(design$informationRates[k + 1]) -
                         .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                         sqrt(design$informationRates[k + 1] - design$informationRates[k])
@@ -157,18 +158,37 @@ NULL
             }
 
             if (adaptations[k]) {
+                selectArmsFunctionArgs <- list(
+                    effectVector = NULL,
+                    stage = k,
+                    conditionalPower = conditionalPower,
+                    conditionalCriticalValue = conditionalCriticalValue,
+                    plannedSubjects = plannedSubjects,
+                    allocationRatioPlanned = allocationRatioPlanned,
+                    selectedArms = selectedArms,
+                    thetaH1 = thetaH1,
+                    stDevH1 = stDevH1,
+                    overallEffects = overallEffects
+                )
+
                 if (effectMeasure == "testStatistic") {
-                    selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallTestStatistics[, k],
-                        typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
-                    ))
+                    selectArmsFunctionArgs$effectVector <- overallTestStatistics[, k]
                 } else if (effectMeasure == "effectEstimate") {
-                    selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallEffects[, k],
-                        typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
-                    ))
+                    selectArmsFunctionArgs$effectVector <- overallEffects[, k]
                 }
 
+                args <- list(
+                    typeOfSelection = typeOfSelection,
+                    epsilonValue = epsilonValue,
+                    rValue = rValue,
+                    threshold = threshold,
+                    selectArmsFunction = selectArmsFunction,
+                    selectArmsFunctionArgs = selectArmsFunctionArgs,
+                    survival = FALSE
+                )
+
+                selectedArms[, k + 1] <- (selectedArms[, k] & do.call(.selectTreatmentArms, args))
+
                 newSubjects <- calcSubjectsFunction(
                     stage = k + 1, # to be consistent with non-multiarm situation, cf. line 37
                     conditionalPower = conditionalPower,
@@ -416,7 +436,7 @@ getSimulationMultiArmMeans <- function(design = NULL, ...,
     simulatedNumberOfActiveArms <- matrix(0, nrow = kMax, ncol = cols)
     simulatedSubjectsPerStage <- array(0, dim = c(kMax, cols, gMax + 1))
     simulatedSuccessStopping <- matrix(0, nrow = kMax, ncol = cols)
-    simulatedFutilityStopping <- matrix(0, cols * (kMax - 1), nrow = kMax - 1, ncol = cols)
+    simulatedFutilityStopping <- matrix(0, nrow = kMax - 1, ncol = cols)
     simulatedConditionalPower <- matrix(0, nrow = kMax, ncol = cols)
     simulatedRejectAtLeastOne <- rep(0, cols)
     expectedNumberOfSubjects <- rep(0, cols)
@@ -434,7 +454,6 @@ getSimulationMultiArmMeans <- function(design = NULL, ...,
     dataNumberOfSubjects <- rep(NA_real_, len)
     dataNumberOfCumulatedSubjects <- rep(NA_real_, len)
     dataRejectPerStage <- rep(NA, len)
-    dataFutilityStop <- rep(NA_real_, len)
     dataSuccessStop <- rep(NA, len)
     dataFutilityStop <- rep(NA, len)
     dataTestStatistics <- rep(NA_real_, len)
