@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8225 $
+## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -46,11 +46,10 @@ NULL
                 piAssumedControlH1 <- piControlH1
             }
             if (is.na(piTreatmentsH1)) {
-                if (directionUpper) {
-                    piAssumedH1 <- min(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
-                } else {
-                    piAssumedH1 <- max(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
-                }
+                piAssumedH1 <- .applyDirectionOfAlternative(
+                    overallRates[selectedArms[1:gMax, stage + 1], stage], 
+                    directionUpper, type = "minMax", phase = "planning"
+                )
             } else {
                 piAssumedH1 <- piTreatmentsH1
             }
@@ -63,7 +62,7 @@ NULL
                     sqrt(pim * (1 - pim) * (1 + allocationRatioPlanned[stage])) +
                     .getQNorm(conditionalPower) * sqrt(piAssumedH1 * (1 - piAssumedH1) +
                         piAssumedControlH1 * (1 - piAssumedControlH1) * allocationRatioPlanned[stage])))^2 /
-                    (max(1e-7, (2 * directionUpper - 1) * (piAssumedH1 - piAssumedControlH1)))^2
+                    (max(1e-07, (2 * directionUpper - 1) * (piAssumedH1 - piAssumedControlH1)))^2
                 newSubjects <- min(
                     max(minNumberOfSubjectsPerStage[stage + 1], newSubjects),
                     maxNumberOfSubjectsPerStage[stage + 1]
@@ -105,7 +104,7 @@ NULL
         weights <- .getWeightsInverseNormal(design)
     }
 
-    for (k in (1:kMax)) {
+    for (k in 1:kMax) {
         if (k == 1) {
             subjectsPerStage[gMax + 1, k] <- trunc(plannedSubjects[k] / allocationRatioPlanned[k])
         } else {
@@ -175,14 +174,15 @@ NULL
                     .getOneMinusQNorm(adjustedPValues[k]) * sqrt(design$informationAtInterim)) /
                     sqrt(1 - design$informationAtInterim)
             } else {
+                criticalValues <- .getCriticalValues(design)
                 if (.isTrialDesignFisher(design)) {
-                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-7))
+                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
+                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
                 } else {
-                    if (design$criticalValues[k + 1] >= 6) {
+                    if (criticalValues[k + 1] >= 6) {
                         conditionalCriticalValue[k] <- Inf
                     } else {
-                        conditionalCriticalValue[k] <- (design$criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
+                        conditionalCriticalValue[k] <- (criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
                             .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                             sqrt(design$informationRates[k + 1] - design$informationRates[k])
                     }
@@ -190,18 +190,39 @@ NULL
             }
 
             if (adaptations[k]) {
+                selectArmsFunctionArgs <- list(
+                    effectVector = NULL,
+                    stage = k,
+                    directionUpper = directionUpper,
+                    conditionalPower = conditionalPower,
+                    conditionalCriticalValue = conditionalCriticalValue,
+                    plannedSubjects = plannedSubjects,
+                    allocationRatioPlanned = allocationRatioPlanned,
+                    selectedArms = selectedArms,
+                    piTreatmentsH1 = piTreatmentsH1,
+                    piControlH1 = piControlH1,
+                    overallRates = overallRates,
+                    overallRatesControl = overallRatesControl
+                )
+
                 if (effectMeasure == "testStatistic") {
-                    selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallTestStatistics[, k] + runif(gMax, -1e-05, 1e-05),
-                        typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
-                    ))
+                    selectArmsFunctionArgs$effectVector <- overallTestStatistics[, k] + runif(gMax, -1e-05, 1e-05)
                 } else if (effectMeasure == "effectEstimate") {
-                    selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(
-                        k, overallEffectSizes[, k] + runif(gMax, -1e-05, 1e-05),
-                        typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction
-                    ))
+                    selectArmsFunctionArgs$effectVector <- overallEffectSizes[, k] + runif(gMax, -1e-05, 1e-05)
                 }
 
+                args <- list(
+                    typeOfSelection = typeOfSelection,
+                    epsilonValue = epsilonValue,
+                    rValue = rValue,
+                    threshold = threshold,
+                    selectArmsFunction = selectArmsFunction,
+                    selectArmsFunctionArgs = selectArmsFunctionArgs,
+                    survival = FALSE
+                )
+
+                selectedArms[, k + 1] <- (selectedArms[, k] & do.call(.selectTreatmentArms, args))
+
                 newSubjects <- calcSubjectsFunction(
                     stage = k + 1, # to be consistent with non-multiarm situation, cf. line 39
                     directionUpper = directionUpper,
@@ -241,11 +262,10 @@ NULL
             }
 
             if (is.na(piTreatmentsH1)) {
-                if (directionUpper) {
-                    piAssumedH1 <- min(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
-                } else {
-                    piAssumedH1 <- max(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
-                }
+                piAssumedH1 <- .applyDirectionOfAlternative(
+                    overallRates[selectedArms[1:gMax, k], k], 
+                    directionUpper, type = "minMax", phase = "planning"
+                )
             } else {
                 piAssumedH1 <- piTreatmentsH1
             }
@@ -342,7 +362,7 @@ NULL
 #' An allocation ratio can be specified referring to the ratio of number of
 #' subjects in the active treatment groups as compared to the control group.
 #'
-#' The definition of \code{pi1H1} and/or \code{piControl} makes only sense if \code{kMax} > 1
+#' The definition of \code{piTreatmentsH1} and/or \code{piControlH1} makes only sense if \code{kMax} > 1
 #' and if \code{conditionalPower}, \code{minNumberOfSubjectsPerStage}, and
 #' \code{maxNumberOfSubjectsPerStage} (or \code{calcSubjectsFunction}) are defined.
 #'
@@ -381,7 +401,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
         gED50 = NA_real_,
         slope = 1,
         intersectionTest = c("Dunnett", "Bonferroni", "Simes", "Sidak", "Hierarchical"), # C_INTERSECTION_TEST_MULTIARMED_DEFAULT
-        directionUpper = TRUE, # C_DIRECTION_UPPER_DEFAULT
+        directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         adaptations = NA,
         typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
         effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
@@ -423,6 +443,9 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
 
     calcSubjectsFunctionIsUserDefined <- !is.null(calcSubjectsFunction)
 
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
+        design, objectType = "power", userFunctionCallEnabled = TRUE)
+    
     simulationResults <- .createSimulationResultsMultiArmObject(
         design                      = design,
         activeArms                  = activeArms,
