@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8232 $
+## |  Last changed: $Date: 2024-09-19 08:22:37 +0200 (Do, 19 Sep 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -56,14 +56,17 @@ NULL
 NULL
 
 #' Parameter Description: Sided
-#' @param sided Is the alternative one-sided (\code{1}) or two-sided (\code{2}), default is \code{1}. Must be a positive integer of length 1.
+#' @param sided Is the alternative one-sided (\code{1}) or two-sided (\code{2}), default is \code{1}. 
+#'    Must be a positive integer of length 1.
 #' @name param_sided
 #' @keywords internal
 NULL
 
 #' Parameter Description: Information Rates
-#' @param informationRates The information rates (that must be fixed prior to the trial),
-#'   default is \code{(1:kMax) / kMax}.
+#' @param informationRates The information rates t_1, ..., t_kMax (that must be fixed prior to the trial),
+#'   default is \code{(1:kMax) / kMax}. For the weighted inverse normal design, the weights are derived
+#'   through w_1 = sqrt(t_1), and w_k = sqrt(t_k - t_(k-1)). For the weighted Fisher's combination test, the 
+#'   weights (scales) are w_k = sqrt((t_k - t_(k-1)) / t_1) (see the documentation).
 #' @name param_informationRates
 #' @keywords internal
 NULL
@@ -265,10 +268,6 @@ NULL
 #' @keywords internal
 NULL
 
-##
-## Sample Size / Power
-##
-
 #' Parameter Description: Alternative
 #' @param alternative The alternative hypothesis value for testing means. This can be a vector of assumed
 #'   alternatives, default is \code{seq(0, 1, 0.2)} (power calculations) or \code{seq(0.2, 1, 0.2)} (sample size calculations).
@@ -283,6 +282,68 @@ NULL
 #' @keywords internal
 NULL
 
+##  Count data
+
+#' Parameter Description: lambda for Counts
+#' @param lambda A numeric value or vector that represents the assumed rate of a homogeneous Poisson process in
+#'   the pooled treatment groups, there is no default.
+#' @name param_lambda_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: theta for Counts
+#' @param theta A numeric value or vector that represents the assumed mean ratios lambda1/lambda2 of a homogeneous
+#' Poisson process, there is no default.
+#' @name param_theta_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: lambda (1) for Counts
+#' @param lambda1 A numeric value or vector that represents the assumed rate of a homogeneous Poisson process in
+#'   the active treatment group, there is no default.
+#' @name param_lambda1_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: lambda (2) for Counts
+#' @param lambda2 A numeric value that represents the assumed rate of a homogeneous Poisson process in
+#'   the control group, there is no default.
+#' @name param_lambda2_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: overdispersion for Counts
+#' @param overdispersion A numeric value that represents the assumed overdispersion of the negative binomial distribution,
+#' default is \code{0}.
+#' @name param_overdispersion_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: fixedExposureTime for Counts
+#' @param fixedExposureTime If specified, the fixed time of exposure per subject for count data, there is no default.
+#' @name param_fixedExposureTime_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: accrualTime for Counts
+#' @param accrualTime If specified, the assumed accrual time interval(s) for the study, there is no default.
+#' @name param_accrualTime_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: accrualIntensity for Counts
+#' @param accrualIntensity If specified, the assumed accrual intensities for the study, there is no default.
+#' @name param_accrualIntensity_counts
+#' @keywords internal
+NULL
+
+#' Parameter Description: followUpTime for Counts
+#' @param followUpTime If specified, the assumed (additional) follow-up time for the study, there is no default.
+#'        The total study duration is \code{accrualTime + followUpTime}.
+#' @name param_followUpTime_counts
+#' @keywords internal
+NULL
+
 ##
 ## Analysis
 ##
@@ -313,9 +374,10 @@ NULL
 #' Parameter Description: Allocation Ratio Planned
 #' @param allocationRatioPlanned The planned allocation ratio \code{n1 / n2} for a two treatment groups
 #'   design, default is \code{1}. For multi-arm designs, it is the allocation ratio relating the active arm(s) to the control.
-#'   For simulating means and rates for a two treatment groups design, it can be a vector of length kMax, the number of stages.
+#'   For simulating means and rates for a two treatment groups design, it can be a vector of length `kMax`, the number of stages.
 #'   It can be a vector of length kMax, too, for multi-arm and enrichment designs.
 #' 	 In these cases, a change of allocating subjects to treatment groups over the stages can be assessed.
+#'   Note that internally `allocationRatioPlanned` is treated as a vector of length `kMax`, not a scalar.
 #' @name param_allocationRatioPlanned
 #' @keywords internal
 NULL
@@ -367,6 +429,7 @@ NULL
 #'     \item \emph{rates}: a value \code{!= 0}
 #'       (or a value \code{!= 1} for testing the risk ratio \code{pi1 / pi2}) can be specified.
 #'     \item \emph{survival data}: a bound for testing H0: \code{hazard ratio = thetaH0 != 1} can be specified.
+#'     \item \emph{count data}: a bound for testing H0: \code{lambda1 / lambda2 = thetaH0 != 1} can be specified.
 #'   }
 #'   For testing a rate in one sample, a value \code{thetaH0} in (0, 1) has to be specified for
 #'   defining the null hypothesis H0: \code{pi = thetaH0}.
@@ -448,7 +511,7 @@ NULL
 
 #' Parameter Description: Minimum Number Of Subjects Per Stage
 #' @param minNumberOfSubjectsPerStage When performing a data driven sample size recalculation,
-#'   the numeric vector \code{minNumberOfSubjectsPerStage} with length kMax determines the
+#'   the numeric vector \code{minNumberOfSubjectsPerStage} with length \code{kMax} determines the
 #'   minimum number of subjects per stage (i.e., not cumulated), the first element
 #'   is not taken into account. For two treatment arms, it is the number of subjects for both treatment arms.
 #'   For multi-arm designs \code{minNumberOfSubjectsPerStage} refers
@@ -459,7 +522,7 @@ NULL
 
 #' Parameter Description: Maximum Number Of Subjects Per Stage
 #' @param maxNumberOfSubjectsPerStage When performing a data driven sample size recalculation,
-#'   the numeric vector \code{maxNumberOfSubjectsPerStage} with length kMax determines the maximum number
+#'   the numeric vector \code{maxNumberOfSubjectsPerStage} with length \code{kMax} determines the maximum number
 #'   of subjects per stage (i.e., not cumulated), the first element is not taken into account.
 #'   For two treatment arms, it is the number of subjects for both treatment arms.
 #'   For multi-arm designs \code{maxNumberOfSubjectsPerStage} refers
@@ -524,8 +587,8 @@ NULL
 NULL
 
 #' Parameter Description: Maximum Number Of Subjects
-#' @param maxNumberOfSubjects \code{maxNumberOfSubjects > 0} needs to be specified.
-#'   For two treatment arms, it is the maximum number of subjects for both treatment arms.
+#' @param maxNumberOfSubjects \code{maxNumberOfSubjects > 0} needs to be specified for power calculations or calculation
+#' of necessary follow-up (count data). For two treatment arms, it is the maximum number of subjects for both treatment arms.
 #' @name param_maxNumberOfSubjects
 #' @keywords internal
 NULL
@@ -753,8 +816,11 @@ NULL
 
 #' Parameter Description: Select Arms Function
 #' @param selectArmsFunction Optionally, a function can be entered that defines the way of how treatment arms
-#' are selected. This function is allowed to depend on \code{effectVector} with length \code{activeArms}
-#' and \code{stage} (see examples).
+#' are selected. This function is allowed to depend on \code{effectVector} with length \code{activeArms}, 
+#' \code{stage}, \code{"conditionalPower"}, \code{"conditionalCriticalValue"}, \code{"plannedSubjects/plannedEvents"}, 
+#' \code{"allocationRatioPlanned"}, \code{"selectedArms"}, \code{"thetaH1"} (for means and survival), \code{"stDevH1"} (for means), 
+#' \code{"overallEffects"}, and for rates additionally: \code{"piTreatmentsH1"}, \code{"piControlH1"}, \code{"overallRates"}, and 
+#' \code{"overallRatesControl"}. 
 #' @name param_selectArmsFunction
 #' @keywords internal
 NULL
@@ -762,7 +828,10 @@ NULL
 #' Parameter Description: Select Populations Function
 #' @param selectPopulationsFunction Optionally, a function can be entered that defines the way of how populations
 #' are selected. This function is allowed to depend on \code{effectVector} with length \code{populations}
-#' and \code{stage} (see examples).
+#' \code{stage}, \code{"conditionalPower"}, \code{"conditionalCriticalValue"}, \code{"plannedSubjects/plannedEvents"}, 
+#' \code{"allocationRatioPlanned"}, \code{"selectedPopulations"}, \code{"thetaH1"} (for means and survival), \code{"stDevH1"} (for means), 
+#' \code{"overallEffects"}, and for rates additionally: \code{"piTreatmentsH1"}, \code{"piControlH1"}, \code{"overallRates"}, and 
+#' \code{"overallRatesControl"}. 
 #' @name param_selectPopulationsFunction
 #' @keywords internal
 NULL
@@ -839,7 +908,14 @@ NULL
 NULL
 
 #' Parameter Description: Plot Settings
-#' @param plotSettings An object of class \code{PlotSettings} created by \code{\link[=getPlotSettings]{getPlotSetting()s}}.
+#' @param plotSettings An object of class \code{PlotSettings} created by \code{\link[=getPlotSettings]{getPlotSettings()}}.
 #' @name param_plotSettings
 #' @keywords internal
 NULL
+
+#' Parameter Description: Planned Calendar Time
+#' @param plannedCalendarTime For simulating count data, the time points where an analysis is planned to be performed.
+#' Should be a vector of length \code{kMax}
+#' @name param_plannedCalendarTime
+#' @keywords internal
+NULL
