@@ -14,8 +14,8 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 7019 $
- * Last changed: $Date: 2023-05-31 07:23:47 +0200 (Mi, 31 Mai 2023) $
+ * File version: $Revision: 8188 $
+ * Last changed: $Date: 2024-09-10 09:56:44 +0200 (Di, 10 Sep 2024) $
  * Last changed by: $Author: pahlke $
  *
  */
@@ -219,7 +219,7 @@ List getSimulationStepMeans(
 		}
 		thetaStandardized = thetaH1 / stDevH1;
 
-		if (!directionUpper) {
+		if (!R_IsNA(directionUpper) && !directionUpper) {
 			thetaH1 = -thetaH1;
 			thetaStandardized = -thetaStandardized;
 		}
@@ -278,7 +278,7 @@ List getSimulationStepMeans(
 				thetaStandardized = thetaStandardized * sqrt(allocationRatio) / (1.0 + allocationRatio);
 			} else {
 				thetaStandardized = thetaStandardized * sqrt(allocationRatio) /
-						sqrt((1.0 + allocationRatio) * (1.0 + thetaH0 * allocationRatio));
+						sqrt((1.0 + allocationRatio) * (1.0 + pow(thetaH0, 2) * allocationRatio));
 			}
 		}
 		simulatedConditionalPower = getOneMinusPNorm(conditionalCriticalValue -
@@ -297,10 +297,10 @@ List getSimulationStepMeans(
 		double allocationRatio = allocationRatioPlanned[k - 1];
 		if (!meanRatio) {
 			nz = (alternative - thetaH0) / stDev * sqrt(allocationRatio * stageSubjects) /
-					(1 + allocationRatio);
+					(1.0 + allocationRatio);
 		} else {
 			nz = (alternative - thetaH0) / stDev * sqrt(allocationRatio * stageSubjects) /
-					sqrt((1 + allocationRatio) * (1 + pow(thetaH0,2) * allocationRatio));
+					sqrt((1.0 + allocationRatio) * (1.0 + pow(thetaH0, 2) * allocationRatio));
 		}
 		if (normalApproximation) {
 			testResult = (2.0 * directionUpper - 1.0) * R::rnorm(nz, 1.0);
@@ -357,7 +357,7 @@ List getSimulationStepMeans(
 		}
 	}
 
-	if (!directionUpper) {
+	if (!R_IsNA(directionUpper) && !directionUpper) {
 		effectEstimate = -effectEstimate;
 	}
 
@@ -378,7 +378,7 @@ Rcpp::XPtr<calcSubjectsFunctionMeansPtr> getSimulationMeansStageSubjectsXPtr() {
   return Rcpp::XPtr<calcSubjectsFunctionMeansPtr>(new calcSubjectsFunctionMeansPtr(&getSimulationMeansStageSubjects));
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getSimulationMeansLoopCpp")]]
 List getSimulationMeansLoopCpp(
 		NumericVector alternative,
 		int kMax,
