@@ -14,13 +14,13 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_design_utilities.R
-## |  Creation date: 08 December 2021, 09:09:22
-## |  File version: $Revision$
-## |  Last changed: $Date$
-## |  Last changed by: $Author$
+## |  Creation date: 08 November 2023, 09:10:53
+## |  File version: $Revision: 8274 $
+## |  Last changed: $Date: 2024-09-26 11:33:59 +0200 (Do, 26 Sep 2024) $
+## |  Last changed by: $Author: pahlke $
 ## |  
 
-context("Testing Design Utility Functions")
+test_plan_section("Testing Design Utility Functions")
 
 
 test_that("'getPiByLambda' and 'getLambdaByPi' produce corresponding results", {
@@ -185,10 +185,12 @@ test_that("'getPiecewiseExponentialDistribution' and 'getPiecewiseExponentialQua
 	piecewiseLambda <- c(0.03, 0.05, 0.08)
 	piecewiseSurvivalTime <- c(0, 16, 22)
 	time <- seq(2, 50, 4)
-	quantile <- getPiecewiseExponentialDistribution(time, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda) 
-	y <- getPiecewiseExponentialQuantile(quantile, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda)
+	quantile <- getPiecewiseExponentialDistribution(time,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda
+	)
+	y <- getPiecewiseExponentialQuantile(quantile,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda
+	)
 
 	expect_equal(y, time, tolerance = 1e-06)
 
@@ -200,10 +202,12 @@ test_that("'ppwexp' and 'qpwexp' produce corresponding results", {
 	piecewiseLambda <- c(0.03, 0.05, 0.08)
 	piecewiseSurvivalTime <- c(0, 16, 22)
 	time <- seq(2, 50, 4)
-	quantile <- ppwexp(time, 
-		s = piecewiseSurvivalTime, lambda = piecewiseLambda) 
-	y <- qpwexp(quantile, 
-		s = piecewiseSurvivalTime, lambda = piecewiseLambda)
+	quantile <- ppwexp(time,
+	    s = piecewiseSurvivalTime, lambda = piecewiseLambda
+	)
+	y <- qpwexp(quantile,
+	    s = piecewiseSurvivalTime, lambda = piecewiseLambda
+	)
 
 	expect_equal(y, time, tolerance = 1e-06)
 
@@ -213,14 +217,17 @@ test_that("'getPiecewiseExponentialDistribution' and 'getPiecewiseExponentialQua
 
 	# @refFS[Formula]{fs:pieceWiseExponentialSurvival}
 	piecewiseSurvivalTime <- list(
-		"<16"      = 0.03, 
-		"16 - <22" = 0.05, 
-		">=22"      = 0.08)
+	    "<16"      = 0.03,
+	    "16 - <22" = 0.05,
+	    ">=22"      = 0.08
+	)
 	time <- seq(2, 50, 4)
-	quantile <- getPiecewiseExponentialDistribution(time, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime) 
-	y <- getPiecewiseExponentialQuantile(quantile, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime)
+	quantile <- getPiecewiseExponentialDistribution(time,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime
+	)
+	y <- getPiecewiseExponentialQuantile(quantile,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime
+	)
 
 	expect_equal(y, time, tolerance = 1e-06)
 
@@ -230,11 +237,12 @@ test_that("'ppwexp' and 'qpwexp' produce corresponding results ('piecewiseSurviv
 
 	# @refFS[Formula]{fs:pieceWiseExponentialSurvival}
 	piecewiseSurvivalTime <- list(
-		"<16"      = 0.03, 
-		"16 - <22" = 0.05, 
-		">=22"      = 0.08)
+	    "<16"      = 0.03,
+	    "16 - <22" = 0.05,
+	    ">=22"      = 0.08
+	)
 	time <- seq(2, 50, 4)
-	quantile <- ppwexp(time, s = piecewiseSurvivalTime) 
+	quantile <- ppwexp(time, s = piecewiseSurvivalTime)
 	y <- qpwexp(quantile, s = piecewiseSurvivalTime)
 
 	expect_equal(y, time, tolerance = 1e-06)
@@ -244,11 +252,12 @@ test_that("'ppwexp' and 'qpwexp' produce corresponding results ('piecewiseSurviv
 test_that("'getPiecewiseExponentialRandomNumbers': test that mean random numbers are as expected", {
 
 	# @refFS[Formula]{fs:pieceWiseExponentialSurvival}
-	set.seed(12345)
+	set.seed(123456)
 	piecewiseSurvivalTime <- c(0, 16, 22)
 	piecewiseLambda <- c(0.003, 0.003, 0.003)
-	y <- 1 / mean(getPiecewiseExponentialRandomNumbers(5000, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda, kappa = 1))
+	y <- 1 / mean(getPiecewiseExponentialRandomNumbers(100000,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime, piecewiseLambda = piecewiseLambda, kappa = 1
+	))
 	expect_equal(y, piecewiseLambda[1], tolerance = 5e-04)
 
 })
@@ -256,10 +265,10 @@ test_that("'getPiecewiseExponentialRandomNumbers': test that mean random numbers
 test_that("'rpwexp': test that mean random numbers are as expected", {
 
 	# @refFS[Formula]{fs:pieceWiseExponentialSurvival}
-	set.seed(12345)
+	set.seed(123456)
 	piecewiseSurvivalTime <- c(0, 16, 22)
 	piecewiseLambda <- c(0.003, 0.003, 0.003)
-	y <- 1 / mean(rpwexp(5000, s = piecewiseSurvivalTime, lambda = piecewiseLambda, kappa = 1))
+	y <- 1 / mean(rpwexp(100000, s = piecewiseSurvivalTime, lambda = piecewiseLambda, kappa = 1))
 
 	expect_equal(y, piecewiseLambda[1], tolerance = 5e-04)
 
@@ -268,13 +277,15 @@ test_that("'rpwexp': test that mean random numbers are as expected", {
 test_that("'getPiecewiseExponentialRandomNumbers': test that mean random numbers are as expected ('piecewiseSurvivalTime' defined as list)", {
 
 	# @refFS[Formula]{fs:pieceWiseExponentialRandomVariable}
-	set.seed(12345)
+	set.seed(123456)
 	piecewiseSurvivalTime <- list(
-		"<16"      = 0.003, 
-		"16 - <22" = 0.003, 
-		">=22"      = 0.003)
-	y <- 1 / mean(getPiecewiseExponentialRandomNumbers(5000, 
-		piecewiseSurvivalTime = piecewiseSurvivalTime, kappa = 1))
+	    "<16"      = 0.003,
+	    "16 - <22" = 0.003,
+	    ">=22"      = 0.003
+	)
+	y <- 1 / mean(getPiecewiseExponentialRandomNumbers(100000,
+	    piecewiseSurvivalTime = piecewiseSurvivalTime, kappa = 1
+	))
 
 	expect_equal(y, 0.003, tolerance = 5e-04)
 
@@ -283,12 +294,13 @@ test_that("'getPiecewiseExponentialRandomNumbers': test that mean random numbers
 test_that("'rpwexp': test that mean random numbers are as expected ('piecewiseSurvivalTime' defined as list)", {
 
 	# @refFS[Formula]{fs:pieceWiseExponentialRandomVariable}
-	set.seed(12345)
+	set.seed(123456)
 	piecewiseSurvivalTime <- list(
-		"<16"      = 0.003, 
-		"16 - <22" = 0.003, 
-		">=22"      = 0.003)
-	y <- 1 / mean(rpwexp(5000, s = piecewiseSurvivalTime, kappa = 1))
+	    "<16"      = 0.003,
+	    "16 - <22" = 0.003,
+	    ">=22"      = 0.003
+	)
+	y <- 1 / mean(rpwexp(100000, s = piecewiseSurvivalTime, kappa = 1))
 
 	expect_equal(y, 0.003, tolerance = 5e-04)
 
@@ -305,40 +317,44 @@ test_that("'.convertStageWiseToOverallValues': test that function is working as
 	x1 <- .convertStageWiseToOverallValues(c(1:5))
 
 	## Comparison of the results of matrixarray object 'x1' with expected results
-	expect_equal(x1[1, ], 1)
-	expect_equal(x1[2, ], 3)
-	expect_equal(x1[3, ], 6)
-	expect_equal(x1[4, ], 10)
-	expect_equal(x1[5, ], 15)
+	expect_equal(x1[1, ], 1, label = paste0("c(", paste0(x1[1, ], collapse = ", "), ")"))
+	expect_equal(x1[2, ], 3, label = paste0("c(", paste0(x1[2, ], collapse = ", "), ")"))
+	expect_equal(x1[3, ], 6, label = paste0("c(", paste0(x1[3, ], collapse = ", "), ")"))
+	expect_equal(x1[4, ], 10, label = paste0("c(", paste0(x1[4, ], collapse = ", "), ")"))
+	expect_equal(x1[5, ], 15, label = paste0("c(", paste0(x1[5, ], collapse = ", "), ")"))
 
 	x2 <- .convertStageWiseToOverallValues(matrix(c(1:5), ncol = 1))
 
 	## Comparison of the results of matrixarray object 'x2' with expected results
-	expect_equal(x2[1, ], 1)
-	expect_equal(x2[2, ], 3)
-	expect_equal(x2[3, ], 6)
-	expect_equal(x2[4, ], 10)
-	expect_equal(x2[5, ], 15)
+	expect_equal(x2[1, ], 1, label = paste0("c(", paste0(x2[1, ], collapse = ", "), ")"))
+	expect_equal(x2[2, ], 3, label = paste0("c(", paste0(x2[2, ], collapse = ", "), ")"))
+	expect_equal(x2[3, ], 6, label = paste0("c(", paste0(x2[3, ], collapse = ", "), ")"))
+	expect_equal(x2[4, ], 10, label = paste0("c(", paste0(x2[4, ], collapse = ", "), ")"))
+	expect_equal(x2[5, ], 15, label = paste0("c(", paste0(x2[5, ], collapse = ", "), ")"))
 
 	x3 <- .convertStageWiseToOverallValues(matrix(c(1:5), nrow = 1))
 
 	## Comparison of the results of matrixarray object 'x3' with expected results
-	expect_equal(x3[1, ], c(1, 2, 3, 4, 5))
+	expect_equal(x3[1, ], c(1, 2, 3, 4, 5), label = paste0("c(", paste0(x3[1, ], collapse = ", "), ")"))
 
 	x4 <- .convertStageWiseToOverallValues(matrix(c(1:5, 1:5), ncol = 2))
 
 	## Comparison of the results of matrixarray object 'x4' with expected results
-	expect_equal(x4[1, ], c(1, 1))
-	expect_equal(x4[2, ], c(3, 3))
-	expect_equal(x4[3, ], c(6, 6))
-	expect_equal(x4[4, ], c(10, 10))
-	expect_equal(x4[5, ], c(15, 15))
+	expect_equal(x4[1, ], c(1, 1), label = paste0("c(", paste0(x4[1, ], collapse = ", "), ")"))
+	expect_equal(x4[2, ], c(3, 3), label = paste0("c(", paste0(x4[2, ], collapse = ", "), ")"))
+	expect_equal(x4[3, ], c(6, 6), label = paste0("c(", paste0(x4[3, ], collapse = ", "), ")"))
+	expect_equal(x4[4, ], c(10, 10), label = paste0("c(", paste0(x4[4, ], collapse = ", "), ")"))
+	expect_equal(x4[5, ], c(15, 15), label = paste0("c(", paste0(x4[5, ], collapse = ", "), ")"))
 
 	x5 <- .convertStageWiseToOverallValues(matrix(sort(rep(1:5, 2)), nrow = 2))
 
 	## Comparison of the results of matrixarray object 'x5' with expected results
-	expect_equal(x5[1, ], c(1, 2, 3, 4, 5))
-	expect_equal(x5[2, ], c(2, 4, 6, 8, 10))
+	expect_equal(x5[1, ], c(1, 2, 3, 4, 5), label = paste0("c(", paste0(x5[1, ], collapse = ", "), ")"))
+	expect_equal(x5[2, ], c(2, 4, 6, 8, 10), label = paste0("c(", paste0(x5[2, ], collapse = ", "), ")"))
+})
 
+test_that("The default value functions for all designs have all arguments included", {
+    testthat::expect_error(.getDesignGroupSequentialDefaultValues(designFun = getDesignGroupSequential), NA)
+    testthat::expect_error(.getDesignFisherDefaultValues(designFun = getDesignFisher), NA)
 })
 
